/*******************************************************************************
 * Copyright (c) 2007-2011 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse;

import java.io.File;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.junit.After;
import org.junit.Before;
import org.vcs.bazaar.client.BazaarClientFactory;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.testUtils.ExpectedStructureFactory;
import org.vcs.bazaar.client.testUtils.ExpectedWorkingTree;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 *
 */
public abstract class TestCaseWithProject extends AbstractCoreTestCase {

	private File testRoot; 
	private IProject project;
	private ExpectedWorkingTree wt;

	public static ExpectedWorkingTree createWorkingTree(IPath path) throws Exception {
		File branchDir = path.toFile();
		branchDir.mkdir();
		final ExpectedWorkingTree wt = ExpectedStructureFactory.getWorkingTree();
        wt.materialize(branchDir);
        File[] filesToAdd = branchDir.listFiles();
		IBazaarClient client = BazaarClientFactory.createClient(BazaarClientFactory.getPreferredClientType());
        client.setWorkDir(branchDir);
        client.init(branchDir);
        client.add(filesToAdd);
        client.commit(filesToAdd, "initial import");
        return wt;
	}

	@Before
	public void setUp() throws Exception {
		testRoot = File.createTempFile("bzr-eclipse", "test");
		testRoot.delete();
		testRoot.mkdir();
		project = WorkspaceUtil.createProject(testRoot, this.getClass().getName());
		System.out.println();
		wt = createWorkingTree(project.getLocation());
		project.refreshLocal(IResource.DEPTH_INFINITE, new NullProgressMonitor());
		BazaarTeamProvider.map(project, BazaarTeamProvider.ID);
	}

	@After
	public void tearDown() throws Exception {
		if(project != null)
			project.delete(true, true, new NullProgressMonitor());
		testRoot.delete();
	}

	/**
	 * return the project
	 * @return
	 */
	public IProject getProject() {
		return project;
	}

	/**
	 * return the expected working tree
	 * @return
	 */
	public ExpectedWorkingTree getWt() {
		return wt;
	}
}
