/*******************************************************************************
 * Copyright (c) 2007-2011 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.listeners;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.core.runtime.Path;
import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.TestCaseWithProject;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 *
 */
public class FileModificationManagerTest extends TestCaseWithProject {

	private boolean isTearDown;
	private IResourceStateListener stateLIstener;

	@Override
    @Before
	public void setUp() throws Exception {
		super.setUp();
		getProject().refreshLocal(IResource.DEPTH_INFINITE, new NullProgressMonitor());
	}

	@Override
    @After
	public void tearDown() throws Exception {
		super.tearDown();
		isTearDown = true;
		EclipseBazaarCore.removeResourceStateListener(stateLIstener);
	}

	/**
	 * Test the event sent by the FileModificationManager when a file is modified
	 *
	 * @throws CoreException
	 * @throws InterruptedException
	 */
	@Test
	public void testSingleFileResourceChanged() throws CoreException, InterruptedException {
		List<IResource> expectedResources = new ArrayList<IResource>(1);
		final IResource file = getProject().getFile(new Path("file_in_root.txt"));
		expectedResources.add(file);
		file.refreshLocal(IResource.DEPTH_INFINITE, new NullProgressMonitor());
		stateLIstener = new IResourceStateListener() {
			int calls = 0;
			public void resourceStateChanged(BzrChangeStateEvent event) {
				calls++;
				if(isTearDown && calls == 2) {
					// we received the close/delete project event
					return;
				}
				Collection<IResource> resources = event.getResources();
				Assert.assertNotNull(resources);
				Assert.assertEquals(1, resources.size());
				for (IResource resource : resources) {
					Assert.assertEquals(file.getProject(), resource);
				}
			}
		};
		EclipseBazaarCore.addResourceStateListener(stateLIstener);
		file.touch(new NullProgressMonitor());
		Thread.sleep(5000);
	}


}
