/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.core.repository;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.assertFalse;

import java.io.File;
import java.net.URISyntaxException;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 *
 */
public class BranchFactoryTest {

	private File tempDir;
	private String branchDir;
	private File theFile;

	@Before
	public void setUp() {
		tempDir = new File(System.getProperty("java.io.tmpdir"));
		branchDir = "C:/Documents and Settings/dangoore/My Documents/EclipseBZRWorkspace/MyProject";
		theFile = new File(tempDir, branchDir);
		theFile.mkdirs();
	}

	@After
	public void tearDown() {
		theFile.delete();
	}

	/**
	 * Test method for {@link org.vcs.bazaar.eclipse.core.repository.BranchFactory#findOrCreateFor(java.net.URI)}.
	 * @throws BazaarException 
	 */
	@Test
	public void testFindOrCreateForURI() throws BazaarException {
		IBzrBranch branch = BranchFactory.findOrCreateFor(theFile.toURI());
		assertNotNull(branch);
		assertEquals(theFile.toURI(), branch.getLocation());
	}

	/**
	 * Test method for {@link org.vcs.bazaar.eclipse.core.repository.BranchFactory#findOrCreateFor(java.lang.String)}.
	 * @throws URISyntaxException
	 * @throws BazaarException 
	 */
	@Test
	public void testFindOrCreateForString() throws URISyntaxException, BazaarException {
		IBzrBranch branch = BranchFactory.findOrCreateFor(theFile.getAbsolutePath());
		assertNotNull(branch);
		assertEquals(theFile.getAbsolutePath(), branch.getBranchLocation().toString());
	}

	/**
	 * Test method for {@link org.vcs.bazaar.eclipse.core.repository.BranchFactory#validateBranch(java.lang.String)}.
	 */
	@Test
	public void testValidateBranch() {
		assertTrue(BranchFactory.validateBranch(theFile.getAbsolutePath()));
		assertFalse(BranchFactory.validateBranch("ftpg://somepath"));
	}

}
