/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.client;

import java.io.File;

import org.vcs.bazaar.client.IBazaarNotifyListener;

/**
 * a redirect to the console
 * @author Piotr Piastucki
 */
public class DelegatingConsoleListener implements IBazaarNotifyListener {

	private IBazaarNotifyListener consoleListener;
	
	private IBazaarNotifyListener getConsoleListener() {
		return consoleListener;
	}

	
	public void setConsoleListener(IBazaarNotifyListener consoleListener) {
		this.consoleListener = consoleListener;
	}

	public void logCommandLine(String commandLine) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.logCommandLine(commandLine);
		}
	}

	public void logRevision(long revision, String path) {
	}

	public void logCompleted(String message) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.logCompleted(message);
		}
	}

	public void logError(String message) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.logError(message);
		}
	}

	public void logMessage(String message) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.logMessage(message);
		}
	}

	public void onNotify(File path) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.onNotify(path);
		}
	}

	public void setCommand(int command) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.setCommand(command);
		}
	}

	public void logCommandOutput(String message) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.logCommandOutput(message);
		}
	}

}
