/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.InputStream;

import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 *
 */
public class CatCommand extends BazaarCommand {

	private IBzrBranch branch;
	private File file;
	private BranchLocation location;
	private BazaarRevision revision;
	private InputStream content;
	private String charsetName;

	public CatCommand(IBzrBranch branch, File file, String charsetName, BazaarRevision revision) {
		this.branch = branch;
		this.file = file;
		this.revision = revision;
		this.charsetName = charsetName;
	}

	public CatCommand(IBzrBranch branch, BranchLocation location, String charsetName, BazaarRevision revision) {
		this.branch = branch;
		this.location = location;
		this.revision = revision;
		this.charsetName = charsetName;
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see org.vcs.bazaar.eclipse.core.commands.IBazaarCommand#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	@Override
    public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.CatCommand_taskName, 1000);
			IBazaarClient client = getClient(branch, true);
			if (file != null) {
				content = client.cat(file, revision, charsetName);
			} else {
				content = client.cat(location, revision, charsetName);
			}
		} catch (BazaarClientException e) {
			if (e.getMessage() != null && e.getMessage().contains("is not present in revision")) {
				content = new ByteArrayInputStream(new byte[0]);
			} else {
				throw BazaarException.wrapException(e);
			}
		} finally {
			monitor.done();
		}
	}

	public InputStream getContent() {
		return content;
	}

}
