/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarProgressListener;

public class CommandProgressListener implements IBazaarProgressListener {

	protected final IProgressMonitor monitor;
	protected int worked;
	protected int maxtotal;

	public CommandProgressListener(IProgressMonitor monitor) {
		this.monitor = monitor;
	}

	Pattern FETCHING_REVISIONS_PATTERN = Pattern.compile(".*?Fetching revisions:Inserting stream:Estimate.*?(\\d+)/(\\d+)"); 

	public void logProgress(String message) {
		if (monitor != null) {
			if (message != null) {
				Matcher m = FETCHING_REVISIONS_PATTERN.matcher(message);
				if (m.matches()) {
					int newWorked = 0;
					if (worked == 0) {
						newWorked = 5;
					}
					/* extract total and completed */
					/* bzr seems to increase both total and completed when it encounters merged revisions */
					int completedWork = Integer.parseInt(m.group(1));
					int totalWork = Integer.parseInt(m.group(2));
					/* calculate new difference between total and completed */
					if (totalWork > maxtotal) {
						maxtotal = totalWork;
					} else if (maxtotal > 0) {
						/* it looks like we made some progress */
						int w = 5 + completedWork * 95 / maxtotal;
						if (w > newWorked) {
							newWorked = w;
						}
					}
					if (newWorked > worked) {
						monitor.worked(newWorked - worked);
						worked = newWorked;
					}
				}
			}
			monitor.setTaskName(message);
		}
	}

}
