/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import java.io.File;
import java.util.List;

import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.IBazaarRevisionSpec;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Piotr Piastucki
 */
public class CreatePatchCommand extends BazaarCommand {

	private final List<IBzrLocalResource> resources;
	private final IBazaarRevisionSpec revision;
	private final Option[] options;
	private String patchContent;
	
	public CreatePatchCommand(List<IBzrLocalResource> resources, IBazaarRevisionSpec revision, Option[] options) {
		this.resources = resources;
		this.revision = revision;
		this.options = options;
	}
	
	@Override
	public void run(IProgressMonitor monitor) throws BazaarException {
		monitor.beginTask(CoreTexts.DiffCommand_diff, 100);
		try {
			List<File> files = getFiles(resources);
			IBazaarClient client = getClient(resources.get(0).getIResource().getProject());
			patchContent = client.diff(files.toArray(new File[0]), revision);
			monitor.worked(100);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

	public String getPatchContent() {
		return patchContent;
	}

}
