/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import java.io.File;
import java.util.List;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @authors Javier Der Derian<br>
 *  	    Guillermo Gonzalez <guillo.gonzo@gmail.com>
 * @BasedOn AddCommand from BzrEclipse
 */
public class IgnoreCommand extends ResourceChangeCommand {

	private final List<? extends IResource> resources;
	private final BzrWorkspaceRoot root;

	public IgnoreCommand(BzrWorkspaceRoot bzrWorkspaceRoot, List<? extends IResource> resources) {
		this.root = bzrWorkspaceRoot;
		this.resources = resources;
	}

	@Override
    public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		try {
			final File rootfile = this.root.getBranch().getFile();
			for (IResource resource : resources) {
				IBzrLocalResource bzrResource = BzrWorkspaceRoot.getBzrResourceFor(resource);
				root.getClient().ignore(rootfile, bzrResource.getBranchRelativePath().toString());
			}
			return resources.toArray(new IResource[0]);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		}
	}
}
