/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.Path;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 *
 */
public class IgnoredCommand extends BazaarCommand {

	private final IResource resource;
	private final Map<IResource, String> ignored = new HashMap<IResource, String>();

	public IgnoredCommand(IResource resource) {
		this.resource = resource;
	}

	@Override
    public void run(IProgressMonitor monitor) throws BazaarException {
		IProgressMonitor subMonitor = EclipseBazaarCore.subProgressMonitorFor(monitor);
		try {
			subMonitor.beginTask("executing ignored", 10);
			final IBazaarClient client = getClient(resource.getProject());
			final Map<String, String> ignored = client.ignored(resource.getLocation().toFile());
			for (Entry<String, String> entry : ignored.entrySet()) {
				IProject project = resource.getProject();
				IPath fullIgnoredPath = new Path(entry.getKey());
				IPath ignoredPath = fullIgnoredPath.removeFirstSegments(fullIgnoredPath.matchingFirstSegments(project.getLocation()));
				IResource resource = project.findMember(ignoredPath);
				this.ignored.put(resource, entry.getValue());
			}
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, resource);
		} finally {
			subMonitor.done();
		}
	}

	public Map<IResource, String> getIgnored() {
		return this.ignored;
	}
}
