/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.IBazaarInfo;
import org.vcs.bazaar.client.commandline.syntax.IInfoOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 *
 */
public class InfoCommand extends BazaarCommand {

	private IBzrBranch branch;
	private IBazaarInfo info;
	private boolean verbose;

	public InfoCommand(IBzrBranch branch) {
		this.branch = branch;
		this.verbose = true;
	}

	public InfoCommand(IBzrBranch branch, boolean verbose) {
		this.branch = branch;
		this.verbose = verbose;
	}

	@Override
    public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask("Info command", 10000);
			IBazaarClient client = getClient(branch, true);
			// to improve performance when only the default info is required
			if(verbose)
				info = client.info(branch.getFile(), IInfoOptions.VERBOSE);
			else
				info = client.info(branch.getFile());
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

	public IBazaarInfo getInfo() {
		return info;
	}

}
