/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.IBazaarItemInfo;
import org.vcs.bazaar.client.commandline.syntax.ILsOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 *
 */
public class LsCommand extends BazaarCommand {

	private IResource resource;
	private boolean ignored;
	private IBazaarItemInfo[] paths;
	
	public LsCommand(IResource resource, boolean ignored) {
		this.resource = resource;
		this.ignored = ignored;
	}

	@Override
    public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask("executing ls", 1000);
			IBazaarClient client = getClient(resource.getProject(), true);
			if(ignored)
				paths = client.ls(resource.getLocation().toFile(), null, ILsOptions.IGNORED, ILsOptions.VERSIONED);
			else
				paths = client.ls(resource.getLocation().toFile(), null, ILsOptions.VERSIONED);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, resource);
		} finally {
			monitor.done();
		}
	}

	public IBazaarItemInfo[] getPaths() {
		return paths;
	}

}
