/*******************************************************************************
 * Copyright (c) 2008-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.commandline.syntax.IMergeOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.listeners.BzrChangeStateEvent;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class MergeCommand extends MetaModifyCommand {

	private final IBzrBranch branch;
	private final BranchLocation location;
	private Option[] options;
	
	public MergeCommand(IBzrBranch branch, BranchLocation location, Option...options) {
		super();
		this.branch = branch;
		this.location = location;
		this.options = options;
	}

	@Override
	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.MergeCommand_taskName, 100);
			monitor.setTaskName(CoreTexts.MergeCommand_taskName);
			IBazaarClient client = getClient(branch);
			monitor.worked(10);
            client.merge(location, options);
		} catch (BazaarClientException e) {
			if (!setPostCommandErrorOnConflicts(e.getMessage())) {
				throw BazaarException.wrapException(e);
			}
		} finally {
			monitor.done();
		}
		return BzrWorkspaceRoot.findProjectsInBranch(branch);
	}

	@Override
	protected int getChangeType() {
		for (Option option : options) {
			if(option.equals(IMergeOptions.PULL)) {
				return BzrChangeStateEvent.BRANCH_STATE_MODIFY;
			}
		}
		return BzrChangeStateEvent.WT_STATE_MODIFY;
	}
}
