/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 *
 */
public class NickCommand extends BazaarCommand {

	private IBzrBranch branch;
	private String nick;

	public NickCommand(IBzrBranch branch) {
		this.branch = branch;
	}

	@Override
    public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.NickCommand_nick, 1000);
			IBazaarClient client = getClient(branch, true);
			monitor.worked(500);
			nick = client.nick(null);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

	public String getNick() {
		return nick.split(System.getProperty("line.separator"))[0];
	}

}
