/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.commandline.syntax.IPushOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 *
 */
public class PushCommand extends BazaarCommand {

	private IBzrBranch branch;
	private BranchLocation location;
	private boolean remember;
	private boolean overwrite;
	private boolean useExsitingDir;

	public PushCommand(IBzrBranch branch, BranchLocation location) {
		this.branch = branch;
		this.location = location;
	}

	@Override
    public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			IBazaarClient client = getClient(branch);
			List<Option> options = new ArrayList<Option>(0);
			if(remember) {
				options.add(IPushOptions.REMEMBER);
			} 
			if(useExsitingDir) {
				options.add(IPushOptions.USE_EXISTING_DIR);
			}
			if (overwrite) {
				options.add(IPushOptions.OVERWRITE);
			}
			client.push(location, options.toArray(new Option[options.size()]));
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

	public void setRemember(boolean remember) {
		this.remember = remember;
	}

	public void setUseExsitingDir(boolean useExsitingDir) {
		this.useExsitingDir = useExsitingDir;
	}

	public void setOverwrite(boolean overwrite) {
		this.overwrite = overwrite;
	}

}
