/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import java.util.regex.Pattern;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.utils.BzrTeamStatus;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Piotr Piastucki
 */
public class RebaseCommand extends StateChangeCommand {

	private final IBzrBranch branch;
	private final BranchLocation location;
	private final Option[] options;
	private BazaarException rebaseConflictsException;
	private static final Pattern CONFLICT_PATTERN = Pattern.compile("conflict occurred");
	
	protected RebaseCommand(IBzrBranch branch) {
		this(branch, null);
	}

	public RebaseCommand(IBzrBranch branch, BranchLocation location, Option...options) {
		this.branch = branch;
		this.location = location;
		this.options = options;
	}

	@Override
	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.RebaseCommand_taskName, 100);
			IBazaarClient client = getClient(branch);
			monitor.worked(10);
            executeInternally(client);
		} catch (BazaarClientException e) {
			if (e.getMessage() != null && CONFLICT_PATTERN.matcher(e.getMessage()).find()) {
				rebaseConflictsException = new BazaarException(BzrTeamStatus.INFO, IStatus.OK, CoreTexts.RebaseConflicts_error, e);
			} else {
				throw BazaarException.wrapException(e);
			}
		} finally {
			monitor.done();
		}
		return BzrWorkspaceRoot.findProjectsInBranch(branch);
	}

	protected void executeInternally(IBazaarClient client) throws BazaarClientException {
		client.rebase(location, options);
	}

	@Override
	protected BazaarException getPostCommandError() {
		return rebaseConflictsException;
	}

}
