/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import java.io.File;
import java.util.List;
import java.util.Map;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.syntax.IRemoveOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 *
 */
public class RemoveCommand extends ResourceChangeCommand {

	private IBzrLocalResource[] resources;

	public RemoveCommand(IBzrLocalResource[] bzrResources) {
		this.resources = bzrResources;
	}

	@Override
    public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		Map<IBzrBranch, List<File>> map = getFilesByBranchMap(resources);
		try {
			monitor.beginTask(CoreTexts.RemoveCommand_removing, resources.length);
			monitor.setTaskName(CoreTexts.RemoveCommand_removing);
			for (IBzrBranch branch : map.keySet()) {
				IBazaarClient client = getClient(branch);
				client.remove(map.get(branch).toArray(new File[0]), IRemoveOptions.KEEP);
			}
			return getIResources(resources);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

}
