/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import java.io.File;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Piotr Piastucki
 */
public class ShelveCommand extends ResourceChangeCommand {

	private List<IBzrLocalResource> resources;
	private Option[] options;
	private boolean shelveBranch;

	public ShelveCommand(List<IBzrLocalResource> resourcesToShelve, boolean shelveBranch, Option[] options) {
		this.resources = resourcesToShelve;
		this.shelveBranch = shelveBranch;
		this.options = options;
	}

	@Override
	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		Map<IBzrBranch, List<File>> map = getFilesByBranchMap(resources);
		try {
			monitor.beginTask(CoreTexts.ShelveCommand_taskName, resources.size());
			List<IResource> resourcesToRefresh = new ArrayList<IResource>(resources.size());
			for (IBzrBranch branch : map.keySet()) {
				IBazaarClient client = BzrWorkspaceRoot.getClient(branch);
				if (shelveBranch) {
					client.shelve(new File[0], options);
				} else {
					client.shelve(map.get(branch).toArray(new File[0]), options);
				}
				resourcesToRefresh.addAll(Arrays.asList(BzrWorkspaceRoot.findProjectsInBranch(branch)));
			}
			monitor.worked(resources.size());
			return resourcesToRefresh.toArray(new IResource[0]);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

}
