/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import java.util.List;

import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.IBazaarShelf;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Piotr Piastucki
 */
public class ShelveListCommand extends BazaarCommand {

	private IBzrBranch branch;
	private List<IBazaarShelf> shelves;
	
	public ShelveListCommand(IBzrBranch branch) {
		this.branch = branch;
	}
	
	@Override
	public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.ShelveListCommand_taskName, 100);
			IBazaarClient client = getClient(branch, true);
			shelves = client.shelveList();
			monitor.worked(100);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

	public List<IBazaarShelf> getShelves() {
		return shelves;
	}

}
