/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.commandline.syntax.ISwitchOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * TODO: should check here if the project is lightweight/heavyweight checkout?
 */
public class SwitchCommand extends StateChangeCommand {

	private IBzrBranch branch;
	private BranchLocation location;
	private boolean force;
	private boolean createBranch;
	

	public SwitchCommand(IBzrBranch branch, BranchLocation location) {
		this.branch = branch;
		this.location = location;
	}

	@Override
	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.bind(CoreTexts.SwitchCommand_taskName, location.toString()), 100);
			monitor.setTaskName(CoreTexts.bind(CoreTexts.SwitchCommand_taskName, location.toString()));
			IBazaarClient client = getClient(branch);
			List<Option> options = new ArrayList<Option>(0);
			if (force) {
				options.add(ISwitchOptions.FORCE);
			}
			if (createBranch) {
				options.add(ISwitchOptions.CREATE_BRANCH);
			}
			client.switchBranch(location, new CommandProgressListener(monitor), options.toArray(new Option[options.size()]));
			return BzrWorkspaceRoot.findProjectsInBranch(branch);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

	public void setForce(boolean force) {
		this.force = force;
	}

	public void setCreateBranch(boolean createBranch) {
		this.createBranch = createBranch;
	}

}
