/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Piotr Piastucki
 */
public class TagCommand extends BazaarCommand {

	private final IBzrBranch branch;
	private final String tagName;
	private final Option[] options;
	
	public TagCommand(IBzrBranch branch, String tagName, Option[] options) {
		this.branch = branch;
		this.tagName = tagName;
		this.options = options;
	}
	
	@Override
	public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.bind(CoreTexts.TagCommand_taskName, branch.getName()), 100);
			monitor.setTaskName(CoreTexts.bind(CoreTexts.TagCommand_taskName, branch.getName()));
			IBazaarClient client = getClient(branch);
			client.tag(tagName, options);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

}
