/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Piotr Piastucki
 */
public class UnShelveCommand extends ResourceChangeCommand {

	private IBzrBranch branch;
	private String shelfId;
	private Option[] options;

	public UnShelveCommand(IBzrBranch branch, String shelfId, Option[] options) {
		this.branch = branch;
		this.shelfId = shelfId;
		this.options = options;
	}

	@Override
	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.UnShelveCommand_taskName, 100);
			monitor.setTaskName(CoreTexts.UnShelveCommand_taskName);
			IBazaarClient client = BzrWorkspaceRoot.getClient(branch);
			client.unShelve(shelfId, options);
			monitor.worked(100);
			return BzrWorkspaceRoot.findProjectsInBranch(branch);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

}
