/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.history;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IStorage;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.team.core.history.IFileRevision;
import org.eclipse.team.core.history.provider.FileRevision;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.IBazaarLogMessage;
import org.vcs.bazaar.eclipse.core.resources.IStorageBazaarRevision;

/**
 *
 * @author Guillermo Gonzalez
 *
 */
public class BazaarFileRevision extends FileRevision {
	IResource resource;

	IBazaarLogMessage logMessage;

	IStorageBazaarRevision storageBazaarRevision;

	BazaarFileRevision parent;

	public BazaarFileRevision(IBazaarLogMessage logMessage, IResource resource) {
		super();
		this.logMessage = logMessage;
		this.resource = resource;
	}

	public BazaarFileRevision(IBazaarLogMessage mergedLog, IResource resource, BazaarFileRevision parentRevision) {
		this(mergedLog, resource);
		this.parent = parentRevision;
	}

	public IBazaarLogMessage getIBazaarLogMessage() {
		return logMessage;
	}

	public String getName() {
		return resource.getName();
	}

	@Override
    public String getContentIdentifier() {
		return logMessage.getRevision().toString();
	}

	public IStorage getStorage(IProgressMonitor monitor) throws CoreException {
		if (storageBazaarRevision == null) {
			storageBazaarRevision = new IStorageBazaarRevision(resource, logMessage.getRevision());
		}
		return storageBazaarRevision;
	}

	public boolean isPropertyMissing() {
		return false;
	}

	public IFileRevision withAllProperties(IProgressMonitor monitor) throws CoreException {
		return null;
	}

	public BazaarFileRevision[] getChildren() {
		List<BazaarFileRevision> childs = new ArrayList<BazaarFileRevision>();
		if(logMessage.getMerged() != null && logMessage.getMerged().size() > 0) {
			for (IBazaarLogMessage mergedLog : logMessage.getMerged()) {
				childs.add(buildChild(mergedLog));
			}
		}
		return childs.toArray(new BazaarFileRevision[0]);
	}

	protected BazaarFileRevision buildChild(IBazaarLogMessage mergedLog) {
		return new BazaarFileRevision(mergedLog, resource, this);
	}

	public boolean hasChildren() {
		return logMessage.getMerged() != null && logMessage.getMerged().size() > 0;
	}

	public boolean hasParent() {
		return parent != null;
	}

	public BazaarFileRevision getParent() {
		return parent;
	}

	public BazaarRevision getRevision() {
		return logMessage.getRevision();
	}

	public int compareRevisionTo(BazaarFileRevision other) {
		if(other != null)
			return logMessage.getRevision().compareTo(other.getRevision());
		return 1;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((getRevision() == null) ? 0 : getRevision().hashCode());
		result = prime * result + ((parent == null) ? 0 : parent.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		final BazaarFileRevision other = (BazaarFileRevision) obj;
		if (parent == null) {
			if (other.parent != null)
				return false;
		} else if (!parent.equals(other.parent))
			return false;
		if (getRevision() == null) {
			if (other.getRevision() != null)
				return false;
		} else if (!getRevision().equals(other.getRevision()))
			return false;
		return true;
	}



}
