/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.model;

import java.util.EnumSet;

import org.vcs.bazaar.client.BazaarStatusKind;
import org.vcs.bazaar.client.IBazaarStatus;

/**
 * @author Piotr Piastucki
 */
public class BzrStatus {

	protected final EnumSet<BazaarStatusKind> statuses = EnumSet.noneOf(BazaarStatusKind.class);

	public boolean isAdded() {
		return contains(BazaarStatusKind.CREATED);
	}

	public boolean isDeleted() {
		return contains(BazaarStatusKind.DELETED);
	}

	public boolean isKindChange() {
		return contains(BazaarStatusKind.KIND_CHANGED);
	}

	public boolean isHasConflicts() {
		return contains(BazaarStatusKind.HAS_CONFLICTS);
	}

	public boolean isModified() {
		return contains(BazaarStatusKind.MODIFIED);
	}

	public boolean isPendingMerge() {
		return contains(BazaarStatusKind.PENDING_MERGE);
	}

	public boolean isRenamed() {
		return contains(BazaarStatusKind.RENAMED);
	}

	public boolean isUnchanged() {
		return contains(BazaarStatusKind.UNCHANGED);
	}

	public boolean isUnknown() {
		return contains(BazaarStatusKind.UNKNOWN);
	}

	public boolean isUnversioned() {
		return contains(BazaarStatusKind.UNVERSIONED);
	}

	public boolean isVersioned() {
		return contains(BazaarStatusKind.VERSIONED);
	}

	public boolean isXBitChanged() {
		return contains(BazaarStatusKind.X_BIT_CHANGED);
	}

	public boolean isIgnored() {
		return contains(BazaarStatusKind.IGNORED);
	}

	public boolean isAnyModifiedStatus() {
		return isHasConflicts() || isKindChange() || isModified() || isRenamed() || isUnknown() || isXBitChanged()
				|| isAdded() || isDeleted();
	}

	public boolean contains(BazaarStatusKind kind) {
		return statuses.contains(kind);
	}

	public BzrStatus(BazaarStatusKind... kinds) {
		for (BazaarStatusKind kind : kinds) {
			statuses.add(kind);
		}
	}

	public BzrStatus(IBazaarStatus aStatus) {
		for (BazaarStatusKind kind : aStatus.getStatuses()) {
			statuses.add(kind);
		}
	}

	public static BzrStatus modified() {
		return new BzrStatus(BazaarStatusKind.MODIFIED);
	}

	public static BzrStatus unchanged() {
		return new BzrStatus(BazaarStatusKind.UNCHANGED);
	}

	public static BzrStatus ignored() {
		return new BzrStatus(BazaarStatusKind.IGNORED);
	}

	public static BzrStatus unknown() {
		return new BzrStatus(BazaarStatusKind.UNKNOWN);
	}

}
