/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.model;

import java.io.File;
import java.io.Serializable;
import java.net.URI;

import org.eclipse.core.runtime.IPath;
import org.vcs.bazaar.client.core.BranchLocation;

/**
 * <p>
 * represents a particular Bazaar branch. The name is an arbitary user-given
 * name of the repository.
 *
 * @see org.vcs.bazaar.eclipse.internal.core.model.BzrBranch
 * </p>
 *
 * @author Guillermo Gonzalez
 *
 *
 */
public interface IBzrBranch extends Comparable<IBzrBranch>, Serializable, IBzrResource {

	// branch directory structure
	public static final String DIR_META_FOLDER = ".bzr"; //$NON-NLS-1$
	public static final String BRANCH_FOLDER = "branch";
	public static final String LOCATION_FILE = "location";
	public static final String REPOSITORY_FOLDER = "repository";

	/**
	 *
	 * @return URI for the root of this project branch
	 */
	public URI getLocation();

	/**
	 *
	 * @return IPath for this branch or null if this branch is remote
	 */
	public IPath getPath();

	/**
	 *
	 * @return IPath for this branch or null if this branch is remote
	 */
	public File getFile();

	/**
	 * <p>
	 * returns if is local, which means that a number of operations can be
	 * performed on it which would not be possible or advisible on remote repos.
	 * </p>
	 */
	public boolean isLocal();

	/**
	 *
	 * @return parentBranch if exists, and null if this is the root branch
	 */
	public IBzrBranch getParent();

	/**
	 * Returns the nick of this branch
	 *
	 * @return
	 */
	public String getNick();

	/**
	 * return true if this is branch is bounded with other
	 * @return
	 */
	public boolean isBound();

	/**
	 * Returns a branch location object
	 * @return
	 * BranchLocation
	 */
	public BranchLocation getBranchLocation();

	/**
	 * <p>
	 * returns if this is a branch binded to a Eclipse Project, which means that a number of operations can be
	 * performed on it which would not be possible or advisible on remote or local branches.
	 * </p>
	 */
	public boolean isProjectBranch();
}
