/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.repository;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectNature;
import org.eclipse.core.resources.IResourceRuleFactory;
import org.eclipse.core.resources.team.IMoveDeleteHook;
import org.eclipse.core.resources.team.ResourceRuleFactory;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.team.core.RepositoryProvider;
import org.eclipse.team.core.TeamException;
import org.eclipse.team.core.history.IFileHistoryProvider;
import org.eclipse.team.core.history.provider.FileHistoryProvider;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.history.BazaarHistoryProvider;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.notifications.Notification;
import org.vcs.bazaar.eclipse.core.notifications.Notification.NotificationCategory;
import org.vcs.bazaar.eclipse.core.resources.BazaarMoveDeleteHook;

/**
 * @author zingo
 * @modifiedBy Guillermo Gonzalez
 *
 */
public class BazaarTeamProvider extends RepositoryProvider {

	public static final String ID = "org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider";
	private static final ResourceRuleFactory RESOURCE_RULE_FACTORY = new ResourceRuleFactory() {};

	private BzrWorkspaceRoot bzrWorkspaceRoot;
	private final FileHistoryProvider fileHistoryProvider = new BazaarHistoryProvider();

	public static void registerProject(IProject project) throws CoreException {
		RepositoryProvider.map(project, ID);
	}

	public BazaarTeamProvider() {
		super();
	}

	@Override
    public String getID() {
		return getClass().getName();
	}

	@Override
    public void configureProject() throws CoreException {
		if (bzrWorkspaceRoot == null) {
			try {
				bzrWorkspaceRoot = new BzrWorkspaceRoot(getProject());
			} catch (Exception e) {
				throw new CoreException(new Status(IStatus.ERROR, "", ""));
			}
		}
	}

	public void deconfigure() throws CoreException {
	}

	@Override
	protected void deconfigured() {
		super.deconfigured();
		bzrWorkspaceRoot = null;
	}

	/**
	 * @see IProjectNature#setProject(IProject)
	 */
	@Override
	public void setProject(IProject project) {
		super.setProject(project);
		if (BzrWorkspaceRoot.isLightweightCheckout(project)) {
//			try {
//				unmap(project);
//			} catch (TeamException e) {
//			}
			EclipseBazaarCore.getDefault().sendNotification(
					new Notification(NotificationCategory.LIGHTWEIGHT_CHECKOUTS));
		}
	}

	@Override
    public IMoveDeleteHook getMoveDeleteHook() {
		return new BazaarMoveDeleteHook();
	}

	@Override
    public IFileHistoryProvider getFileHistoryProvider() {
		return fileHistoryProvider;
	}

	@Override
	public IResourceRuleFactory getRuleFactory() {
		return RESOURCE_RULE_FACTORY;
	}

	@Override
	public boolean canHandleLinkedResourceURI() {
		return true;
	}

	// Convenience methods
	public IBzrBranch getBranch() {
		return getBzrWorkspaceRoot().getBranch();
	}

	public BzrWorkspaceRoot getBzrWorkspaceRoot() {
		if (bzrWorkspaceRoot == null) {
			try {
				bzrWorkspaceRoot = new BzrWorkspaceRoot(getProject());
			} catch (Exception e) {
				try {
					unmap(getProject());
				} catch (TeamException e1) {
				}
			}
		}
		return bzrWorkspaceRoot;
	}

}
