/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.core.repository;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.team.core.RepositoryProvider;
import org.eclipse.team.core.RepositoryProviderType;
import org.eclipse.team.core.subscribers.Subscriber;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.ITracingOptions;
import org.vcs.bazaar.eclipse.core.subscriber.BazaarStatusSuscriber;
import org.vcs.bazaar.eclipse.core.utils.BzrTeamStatus;
import org.vcs.bazaar.eclipse.core.utils.ResourceUtil;

/**
 * <p>
 * A repository provider type implementation for Bazaar.
 * </p>
 * <p>
 * A type provider manage non-local repositories
 * </p>
 *
 * @author Guillermo Gonzalez
 *
 */
public class BazaarTeamProviderType extends RepositoryProviderType {

	@Override
	public void metaFilesDetected(final IProject project, final IContainer[] containers) {
		EclipseBazaarCore.trace(ITracingOptions.TEAM_PROVIDER, "metaFilesDetected: ", project);
		super.metaFilesDetected(project, containers);
		if (ResourceUtil.isUnderBazaarScope(project)) {
			Job job = new BackgroundJob(CoreTexts.BazaarTeamProviderType_backgroundJobName, project);
			job.schedule();
		}
	}

	public static void registerProject(IProject project) throws CoreException {
		BazaarTeamProvider.registerProject(project);
	}

	@Override
	public Subscriber getSubscriber() {
		return BazaarStatusSuscriber.getInstance();
	}

	protected static class BackgroundJob extends Job {

		final IProject project;
		final static int processWork = 100;

		/**
		 * @param name
		 */
		public BackgroundJob(String name, IProject project) {
			super(name);
			this.project = project;
		}

		/**
		 * FIXME: support for multiple projects per branch
		 */
		@Override
		protected IStatus run(final IProgressMonitor monitor) {
			IStatus result = BzrTeamStatus.OK_STATUS;
			try {
				monitor.beginTask(getName(), processWork);
				if (RepositoryProvider.getProvider(project) == null) {
					registerProject(project);
				}
			} catch (CoreException e) {
				result = e.getStatus();
			} finally {
				monitor.done();
			}
			return result;
		}

	}
}
