/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.repository;

import java.net.URI;
import java.util.HashMap;
import java.util.Map;

import org.eclipse.core.resources.IProject;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.utils.ResourceUtil;
import org.vcs.bazaar.eclipse.internal.core.model.LocalBranch;
import org.vcs.bazaar.eclipse.internal.core.model.LpBranch;
import org.vcs.bazaar.eclipse.internal.core.model.ProjectBranch;
import org.vcs.bazaar.eclipse.internal.core.model.RemoteBranch;

/**
 * Contributor: Alexander Taler
 * 
 * @author Guillermo Gonzalez
 */
public class BranchFactory {

	private static Map<BranchLocation, ProjectBranch> PROJECT_BRANCHES = new HashMap<BranchLocation, ProjectBranch>();
	
    public static IBzrBranch getBranch(BranchLocation location) {
    	if ("file".equals(location.getScheme())) {
            return new LocalBranch(location);
        } else if ("lp".equals(location.getScheme())) {
            return new LpBranch(location);
        }
        return new RemoteBranch(location);
    }
	
	/**
	 * @param URI
	 *
	 * @return IBzrBranch for the given URI (or null if there is no branch)
	 * TODO: this method should only return RemoteBranch instances?
	 */
	public static IBzrBranch findOrCreateFor(URI uri) {
		try {
			return getBranch(new BranchLocation(uri));
		} catch (BazaarClientException e) {
		}
		return null;
	}

	/**
	 * @param URI
	 *            as String
	 * @return IBzrBranch for the given URI (or null if there is no branch)
	 */
	public static IBzrBranch findOrCreateFor(String uri) {
		try {
			return getBranch(new BranchLocation(uri));
		} catch (BazaarClientException e) {
		}
		return null;
	}

	
	
	/**
	 * @param IProject
	 *            which this branch belongs
	 * @return a LocalBranch that for the localProject, with it's .bzr folder in
	 *         the project root folder or it parent
	 */
	public static synchronized ProjectBranch findOrCreateFor(IProject project) {
		try {
			BranchLocation location = new BranchLocation(ResourceUtil.findRootLocation(project).toOSString());
			if (!PROJECT_BRANCHES.containsKey(location)) {
				PROJECT_BRANCHES.put(location, new ProjectBranch(location));
			}
			return PROJECT_BRANCHES.get(location);
		} catch (BazaarClientException e) {
		}
		return null;
	}

	/**
	 * Check if the URI contains a valid branch
	 *
	 * @param uri
	 * @return boolean
	 */
	public static boolean validateBranch(String uri) {
		try {
			new BranchLocation(uri);
		} catch (Exception e) {
			return false;
		}
		return true;
	}
}
