/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.status;

import java.util.Collection;
import java.util.HashSet;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.locks.ReentrantLock;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IResource;
import org.vcs.bazaar.eclipse.core.model.BzrStatus;

/**
 * @author Piotr Piastucki
 */
public class StatusCacheEntry {

	private long fullReloadTimestamp;
	private final ReentrantLock lock = new ReentrantLock(true);
	private Map<IResource, BzrStatus> statusMap = new ConcurrentHashMap<IResource, BzrStatus>();
	private final HashSet<IContainer> pseudoModifiedContainers = new HashSet<IContainer>();
	private final LastLogCacheEntry logCache = new LastLogCacheEntry();

	public long getFullReloadTimestamp() {
		return fullReloadTimestamp;
	}

	public void setFullReloadTimestamp(Long fullReloadTimestamp) {
		this.fullReloadTimestamp = fullReloadTimestamp;
	}

	public boolean isInitialized() {
		return fullReloadTimestamp != 0;
	}

	public void update(Map<IResource, BzrStatus> statusMap) {
		this.statusMap = new ConcurrentHashMap<IResource, BzrStatus>(statusMap);
	}

	public Map<IResource, BzrStatus> getStatusMap() {
		return statusMap;
	}

	public BzrStatus get(IResource resource) {
		return statusMap.get(resource);
	}

	public boolean isPseudoModified(IContainer container) {
		return pseudoModifiedContainers.contains(container);
	}

	public boolean setPseudoModified(IContainer container) {
		return pseudoModifiedContainers.add(container);
	}

	public boolean removePseudoModified(IContainer container) {
		return pseudoModifiedContainers.add(container);
	}

	public void removePseudoModified(Collection<IResource> resources) {
		pseudoModifiedContainers.removeAll(resources);
	}

	public ReentrantLock getLock() {
		return lock;
	}

	public LastLogCacheEntry getLogCache() {
		return logCache;
	}
	
}
