/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.subscriber;

import java.io.BufferedInputStream;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.team.core.TeamException;
import org.eclipse.team.core.variants.CachedResourceVariant;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.resources.IStorageBazaarRevision;

/**
 * @author Guillermo Gonzalez
 *
 */
public class BazaarResourceVariant extends CachedResourceVariant {

	private IStorageBazaarRevision storage;
	private byte[] bytes;

	public BazaarResourceVariant(IStorageBazaarRevision file) {
		super();
		this.storage = file;
	}

	@Override
	protected void fetchContents(IProgressMonitor monitor) throws TeamException {
		try {
			setContents(new BufferedInputStream(storage.getContents()), monitor);
		} catch (CoreException e) {
			throw TeamException.asTeamException(e);
		}
	}

	@Override
	protected String getCacheId() {
		return EclipseBazaarCore.getPluginId();
	}

	@Override
	protected String getCachePath() {
		return storage.getCachePath();
	}

	public byte[] asBytes() {
		if (bytes == null) {
			bytes = getCachePath().getBytes();
		}
		return bytes;
	}

	public String getContentIdentifier() {
		return storage.getRevision().toString();
	}

	public String getName() {
		return storage.getName();
	}

	public boolean isContainer() {
		return storage.isContainer();
	}

}
