/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.synchronize;

import org.vcs.bazaar.client.BazaarRevision;

/**
 * @author Piotr Piastucki
 */
public class BazaarSyncCacheEntry {

	public static enum ChangeType {
		ADD,
		MODIFY,
		DELETE,
	}

	/** Change direction */
	public static enum Direction {
		INCOMING,
		OUTGOING,
		CONFLICTING
	}

	private final String path;
	private final Direction direction;
	private final ChangeType changeType;
	private final BazaarRevision baseRevision;
	private final BazaarRevision remoteRevision;
	private final boolean directory; 
	
	public BazaarSyncCacheEntry(String path, Direction direction, ChangeType changeType, BazaarRevision baseRevision, 
			BazaarRevision remoteRevision, boolean directory) {
		this.path = path;
		this.direction = direction;
		this.changeType = changeType;
		this.baseRevision = baseRevision;
		this.remoteRevision = remoteRevision;
		this.directory = directory;
	}

	public String getPath() {
		return path;
	}

	public Direction getDirection() {
		return direction;
	}

	public ChangeType getChangeType() {
		return changeType;
	}

	public BazaarRevision getBaseRevision() {
		return baseRevision;
	}

	public BazaarRevision getRemoteRevision() {
		return remoteRevision;
	}

	public boolean isDirectory() {
		return directory;
	}

}
