/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.synchronize;

import java.io.File;
import java.util.List;
import java.util.Map;

import org.eclipse.core.resources.IProject;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.BazaarTreeStatus;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.IBazaarLogMessage;
import org.vcs.bazaar.client.commandline.syntax.IMissingOptions;
import org.vcs.bazaar.client.commandline.syntax.IStatusOptions;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;

/**
 * @author Piotr Piastucki
 */
public class BazaarSyncCacheManager {

	public static BazaarSyncCache getCache(BazaarSynchronizeData syncData) {
		try {
			IProject project = syncData.getProjects()[0];
			IBazaarClient client = BzrWorkspaceRoot.getBzrWorkspaceRootFor(project).getClient();
			IBzrBranch branch =  BzrWorkspaceRoot.getBranchFor(project);
			/* get difference between base and remote */
			Map<String, List<IBazaarLogMessage>> missing = client.missing(branch.getFile(), syncData.getRemoteLocation(), IMissingOptions.VERBOSE);
			List<IBazaarLogMessage> mine = missing.get("MINE");
			List<IBazaarLogMessage> other = missing.get("OTHER");
			/* get difference between base and local */
			BazaarTreeStatus status = client.status(new File[] { branch.getFile() }, IStatusOptions.VERSIONED);
			/* get current local revision */
			BazaarRevision revno = client.revno(branch.getBranchLocation());
			return new BazaarSyncCache(branch.getPath(), mine, other, status, revno);
		} catch (Exception e) {
			EclipseBazaarCore.log(e.getMessage(), e);
		}
		return null;
	}
}
