/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.synchronize;

import org.eclipse.core.resources.IResource;
import org.eclipse.team.core.synchronize.SyncInfo;
import org.eclipse.team.core.variants.IResourceVariant;
import org.eclipse.team.core.variants.IResourceVariantComparator;
import org.vcs.bazaar.eclipse.core.synchronize.BazaarSyncCacheEntry.ChangeType;
import org.vcs.bazaar.eclipse.core.synchronize.BazaarSyncCacheEntry.Direction;

/**
 * @author Piotr Piastucki
 */
public class BazaarSyncInfo extends SyncInfo {

	private final BazaarSyncCacheEntry cached;
	
	public BazaarSyncInfo(BazaarSyncCacheEntry cached, IResource local, 
								IResourceVariant base, IResourceVariant remote, IResourceVariantComparator comparator) {
		super(local, base, remote, comparator);
		this.cached = cached;
	}

	@Override
	protected int calculateKind() {
		if (cached == null) {
			return IN_SYNC;
		}

		int direction;
		Direction gitDirection = cached.getDirection();
		if (gitDirection == Direction.INCOMING) {
			direction = INCOMING;
		} else if (gitDirection == Direction.OUTGOING) {
			direction = OUTGOING;
		} else {
			direction = CONFLICTING;
		}

		ChangeType changeType = cached.getChangeType();

		if (changeType == ChangeType.MODIFY) {
			return direction | CHANGE;
		} else if (changeType == ChangeType.ADD) {
			return direction | ADDITION;
		} else if (changeType == ChangeType.DELETE) {
			return direction | DELETION;
		}
		return IN_SYNC;
	}

}
