/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.synchronize;

import java.util.HashSet;
import java.util.Set;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IPath;
import org.vcs.bazaar.client.core.BranchLocation;

/**
 * @author Piotr Piastucki
 */
public class BazaarSynchronizeData {

	private final IResource[] resources;
	private final BranchLocation location;
	private final Set<IProject> projects;
	
	public BazaarSynchronizeData(IResource[] resources, BranchLocation location) {
		projects = new HashSet<IProject>();
		for (IResource resource : resources) {
			projects.add(resource.getProject());
		}
		this.resources = resources;
		this.location = location;
	}
	
	public boolean isIncluded(IResource resource) {
		if (resource == null || resource.getProject() == null) {
			return false;
		}
		if (!projects.contains(resource.getProject())) {
			return false;
		}
		IPath path = resource.getLocation();
		for (IResource res : resources) {
			if (res.getLocation().isPrefixOf(path)) {
				return true;
			}
		}
		return false;
	}

	public IProject[] getProjects() {
		return projects.toArray(new IProject[projects.size()]);
	}

	public IResource[] getResources() {
		return resources;
	}

	public BranchLocation getRemoteLocation() {
		return location;
	}
}
