/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.internal.core.model;

import org.vcs.bazaar.client.BazaarStatusKind;
import org.vcs.bazaar.client.IBazaarStatus;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;

/**
 * @author Guillermo Gonzalez
 *
 */
public class BzrResourceStatus implements IBzrResourceStatus {

	private final IBazaarStatus status;
	private final IBzrLocalResource resource;

	public BzrResourceStatus(IBzrLocalResource resource, IBazaarStatus status) {
		this.resource = resource;
		this.status = status;
	}

	public IBzrLocalResource getResource() {
		return resource;
	}

	public boolean contains(BazaarStatusKind kind) {
		return status.contains(kind);
	}

	public IBazaarStatus getStatus() {
		return status;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((resource == null) ? 0 : resource.hashCode());
		result = prime * result + ((status == null) ? 0 : status.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		final BzrResourceStatus other = (BzrResourceStatus) obj;
		if (resource == null) {
			if (other.resource != null)
				return false;
		} else if (!resource.equals(other.resource))
			return false;
		if (status == null) {
			if (other.status != null)
				return false;
		} else if (!status.equals(other.status))
			return false;
		return true;
	}

	public boolean isAdded() {
		return contains(BazaarStatusKind.CREATED);
	}
	public boolean isDeleted() {
		return contains(BazaarStatusKind.DELETED);
	}
	public boolean isKindChange() {
		return contains(BazaarStatusKind.KIND_CHANGED);
	}
	public boolean isHasConflicts() {
		return contains(BazaarStatusKind.HAS_CONFLICTS);
	}
	public boolean isModified() {
		return contains(BazaarStatusKind.MODIFIED);
	}
	public boolean isPendingMerge() {
		return contains(BazaarStatusKind.PENDING_MERGE);
	}
	public boolean isRenamed() {
		return contains(BazaarStatusKind.RENAMED);
	}
	public boolean isUnchanged() {
		return contains(BazaarStatusKind.UNCHANGED);
	}
	public boolean isUnknown() {
		return contains(BazaarStatusKind.UNKNOWN);
	}
	public boolean isUnversioned() {
		return contains(BazaarStatusKind.UNVERSIONED);
	}
	public boolean isVersioned() {
		return contains(BazaarStatusKind.VERSIONED);
	}
	public boolean isXBitChanged() {
		return contains(BazaarStatusKind.X_BIT_CHANGED);
	}
	public boolean isIgnored() {
		return contains(BazaarStatusKind.IGNORED);
	}
	public boolean isAnyModifiedStatus() {
		return isHasConflicts() || isKindChange() || isModified() || isRenamed() || isUnknown() 
				|| isXBitChanged() || isAdded() || isDeleted();
	}

}
