/**
 * LICENCSE + COPYRIGHT
 * Copyright (c) 2004-2006 by Leif Frenzel - see http://leiffrenzel.de
 */
package org.vcs.bazaar.eclipse.internal.core.model;

import java.util.List;
import java.util.Map;

import org.eclipse.core.runtime.NullProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.IBazaarInfo;
import org.vcs.bazaar.client.IBazaarLogMessage;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.InfoCommand;
import org.vcs.bazaar.eclipse.core.commands.MetaModifyCommand;
import org.vcs.bazaar.eclipse.core.commands.NickCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.IBzrMissingRevisions;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * <p>
 * Implementation of a branch, which corresponds to a project in the workspace.
 * </p>
 *
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class ProjectBranch extends LocalBranch  {

	private static final long serialVersionUID = 1L;
	/** keep a cached info and a dirty flag which is set by {@link MetaModifyCommand} */
	private IBazaarInfo info;
	private String nick;
	private boolean dirty = true;
	private boolean dirtyNick = true;

	public ProjectBranch(final BranchLocation location) {
		super(location);
		// make sure the URI scheme is "file"
		assert ("file".equals(getLocation().getScheme()));
	}

	@Override
	public String getNick() {
		try {
			if (nick == null || dirtyNick) {
				NickCommand cmd = new NickCommand(this);
				cmd.run(new NullProgressMonitor());
				nick = cmd.getNick();
				dirtyNick = false;
			}
		} catch (BazaarException e) {
			EclipseBazaarCore.log(e.getMessage(), e);
			nick = null;
		}
		return nick;
	}

	@Override
	public IBazaarInfo getInfo() {
		try {
			if (info == null || dirty) {
				InfoCommand cmd = new InfoCommand(this, false);
				cmd.run(new NullProgressMonitor());
				info = cmd.getInfo();
				dirty = false;
			}
		} catch (BazaarException e) {
			EclipseBazaarCore.log(e.getMessage(), e);
			info = null;
		}
		return info;
	}

	@Override
	public IBzrMissingRevisions getMissing(IBzrBranch otherBranch) throws BazaarException {
		return new BzrMissingRevisions(calculateMissing(otherBranch));
	}

	protected Map<String, List<IBazaarLogMessage>> calculateMissing(IBzrBranch otherBranch) throws BazaarException {
		Map<String, List<IBazaarLogMessage>> result = null;
		IBazaarClient client = null;
		try {
			client = BzrWorkspaceRoot.getClient(this, true);
			result = client.missing(getFile(), otherBranch.getBranchLocation());
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
		}
		return result;
	}

	@Override
    public boolean isProjectBranch() {
		return true;
	}

	public void setDirty(boolean dirty) {
		this.dirty = dirty;
		this.dirtyNick = dirty;
	}

}