/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.internal.core.model;

import java.io.File;
import java.net.URI;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IPath;
import org.vcs.bazaar.client.core.BranchLocation;

/**
 * <p>
 * default implementation of a remote branch location.
 * </p>
 *
 * @author Guillermo Gonzalez
 *
 */
public class RemoteBranch extends BzrBranch {

	private static final long serialVersionUID = 1L;

	public RemoteBranch(BranchLocation location) {
		super(location);
	}

	public boolean isLocal() {
		return false;
	}

	public String getNick() {
		// nick command don't work on remote branches
		return null;
	}

	@Override
    public URI getLocation() {
		return location.getUri();
	}

	public IProject getProject() {
		// no project in a remote branch, right?
		return null;
	}

	public File getFile() {
		return null;
	}

	@Override
    public IPath getPath() {
		// we handle all remote branches by they URI
		return null;
	}

	@Override
	public BranchLocation getBranchLocation() {
		return location;
	}

}
