/*******************************************************************************
 * Copyright (C) 2007, Robin Rosenberg <robin.rosenberg@dewire.com>
 * Copyright (C) 2008, Roger C. Soares <rogersoares@intelinet.com.br>
 * Copyright (C) 2007, Shawn O. Pearce <spearce@spearce.org>
 * Copyright (C) 2010, Chris Aniszczyk <caniszczyk@gmail.com>
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * Contributors:
 *    Piotr Piastucki - Copied from egit project and adapted to bzr-eclipse
 *******************************************************************************/

package org.vcs.bazaar.eclipse.ui;

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.jface.resource.ImageDescriptor;

/**
 * @author Piotr Piastucki
 */
public class UIIcons {

	public final static ImageDescriptor REFRESH;
	public final static ImageDescriptor CHECK_ALL;
	public final static ImageDescriptor UNCHECK_ALL;

	/** Untracked file icon */
	public final static ImageDescriptor UNTRACKED_FILE;

	/** Affected paths switch button */
	public final static ImageDescriptor AFFECTED_PATHS;

	/** Tree view branch item */
	public final static ImageDescriptor TREE_VIEW_BRANCH;

	/** Tree view tags item */
	public final static ImageDescriptor TREE_VIEW_TAGS;

	/** Tree view tags item */
	public final static ImageDescriptor TREE_VIEW_TAG;

	/** Tree view remotes item */
	public final static ImageDescriptor TREE_VIEW_REMOTES;

	/** Bazaar wizard banner */
	public final static ImageDescriptor WIZBAN;

	/** Share project wizard banner */
	public final static ImageDescriptor WIZBAN_SHARE;

	/** Create patch wizard banner */
	public final static ImageDescriptor WIZBAN_CREATE_PATCH;

	public final static ImageDescriptor EXPAND_ALL;

	public final static ImageDescriptor COMMENT;

	public final static ImageDescriptor TEMPLATE;

	/** base URL */
	public final static URL base;

	static {
		base = init();
		REFRESH = map("refresh.gif"); //$NON-NLS-1$
		EXPAND_ALL = map("expandall.gif"); //$NON-NLS-1$
		CHECK_ALL = map("check_all.gif"); //$NON-NLS-1$
		UNCHECK_ALL = map("uncheck_all.gif"); //$NON-NLS-1$
		UNTRACKED_FILE = map("untracked_file.gif"); //$NON-NLS-1$
		AFFECTED_PATHS = map("flat_layout.gif"); //$NON-NLS-1$
		TREE_VIEW_BRANCH = map("tree/branch.gif"); //$NON-NLS-1$
		TREE_VIEW_TAGS = map("tree/tags.gif"); //$NON-NLS-1$
		TREE_VIEW_TAG = map("tree/tag.gif"); //$NON-NLS-1$
		TREE_VIEW_REMOTES = map("tree/remotes.gif"); //$NON-NLS-1$
		WIZBAN = map("wizban.png"); //$NON-NLS-1$
		WIZBAN_SHARE = map("wizban_share.png"); //$NON-NLS-1$
		WIZBAN_CREATE_PATCH = map("wizban_createpatch.png"); //$NON-NLS-1$
		COMMENT = map("comment.gif"); //$NON-NLS-1$
		TEMPLATE = map("template.gif"); //$NON-NLS-1$
	}	

	private static ImageDescriptor map(final String icon) {
		if (base != null)
			try {
				return ImageDescriptor.createFromURL(new URL(base, icon));
			} catch (MalformedURLException mux) {
			}
		return ImageDescriptor.getMissingImageDescriptor();
	}

	private static URL init() {
		try {
			return new URL(EclipseBazaarUI.getDefault().getBundle().getEntry("/"), //$NON-NLS-1$
					"icons/"); //$NON-NLS-1$
		} catch (Exception e) {
			return null;
		}
	}
}
