/*******************************************************************************
 * Copyright (c) 2010, 2012 SAP AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Mathias Kinzler (SAP AG) - initial implementation
 *    Piotr Piastucki - ported to bzr-eclipse
 *******************************************************************************/

package org.vcs.bazaar.eclipse.ui;

import org.eclipse.core.runtime.Path;
import org.eclipse.jface.fieldassist.ControlDecoration;
import org.eclipse.jface.fieldassist.FieldDecorationRegistry;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ControlEvent;
import org.eclipse.swt.events.ControlListener;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.TableColumn;
import org.eclipse.swt.widgets.TreeColumn;
import org.eclipse.ui.ISharedImages;
import org.eclipse.ui.PlatformUI;
import org.vcs.bazaar.client.IBazaarStatus;

/**
 * @author Piotr Piastucki
 */
public class UIUtils {

	public static void addBulbDecorator(final Control control, final String tooltip) {
		ControlDecoration dec = new ControlDecoration(control, SWT.TOP | SWT.LEFT);

		dec.setImage(FieldDecorationRegistry.getDefault()
				.getFieldDecoration(FieldDecorationRegistry.DEC_CONTENT_PROPOSAL).getImage());

		dec.setShowOnlyOnFocus(true);
		dec.setShowHover(true);
		dec.setDescriptionText(tooltip);
	}

	public static Font getFont(final String id) {
		return PlatformUI.getWorkbench().getThemeManager().getCurrentTheme()
				.getFontRegistry().get(id);
	}

	public static ImageDescriptor getEditorImage(final IBazaarStatus status) {
		if (status.isDirectory()) {
			return PlatformUI.getWorkbench().getSharedImages().getImageDescriptor(ISharedImages.IMG_OBJ_FOLDER);
		}
		return getEditorImage(status.getPath());
	}

	public static ImageDescriptor getEditorImage(final String path) {
		if (path != null && path.length() > 0) {
			final String name = new Path(path).lastSegment();
			if (name != null) {
				return PlatformUI.getWorkbench().getEditorRegistry().getImageDescriptor(name);
			}
		}
		return PlatformUI.getWorkbench().getSharedImages().getImageDescriptor(ISharedImages.IMG_OBJ_FILE);
	}

	public static String getFirstLine(String text) {
		int nlIndex = text.indexOf('\n');
		if (nlIndex > 0) {
			text = text.substring(0, nlIndex);
		}
		return text;
	}

	/* prevent columns from being resized to 0 */
	public static void addSizeLimiter(final TableColumn column) {
		if (column != null) {
			column.addControlListener(new ControlListener() {
				public void controlResized(ControlEvent e) {
					if (column.getWidth() < 5) {
						column.setWidth(5);
					}
				}
				public void controlMoved(ControlEvent e) {
				}
			});
		}
	}
	
	public static void addSizeLimiter(final TreeColumn column) {
		if (column != null) {
			column.addControlListener(new ControlListener() {
				public void controlResized(ControlEvent e) {
					if (column.getWidth() < 5) {
						column.setWidth(5);
					}
				}
				public void controlMoved(ControlEvent e) {
				}
			});
		}
	}

}
