/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.util.Arrays;
import java.util.List;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.team.core.history.provider.FileRevision;
import org.eclipse.ui.actions.BaseSelectionListenerAction;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.BazaarRevisionRange;
import org.vcs.bazaar.client.IBazaarRevisionSpec;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.commands.StatusCommand;
import org.vcs.bazaar.eclipse.core.history.BazaarFileRevision;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.core.resources.IStorageBazaarRevision;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.compare.CompareUtils;

public abstract class AbstractCompareAction extends BaseSelectionListenerAction {

	protected AbstractCompareAction(String text) {
		super(text);
	}

	@Override
	public void run() {
		internalRun();
	}

	protected abstract void internalRun();

	@Override
	protected boolean updateSelection(IStructuredSelection selection) {
		return shouldShow(selection);
	}

	protected abstract boolean shouldShow(IStructuredSelection selection);

	protected BazaarFileRevision getRevision(int selectionIdx) throws CoreException {
		IStructuredSelection selection = getStructuredSelection();
		Object[] revs = selection.toArray();
		if (selectionIdx >= revs.length)
			return null;
		return (BazaarFileRevision) revs[selectionIdx];
	}

	protected IStorageBazaarRevision getStorage(int selectionIdx) throws CoreException {
		IStructuredSelection selection = getStructuredSelection();
		Object[] revs = selection.toArray();
		if (selectionIdx >= revs.length)
			return null;
		FileRevision rev = (FileRevision) revs[selectionIdx];
		return (IStorageBazaarRevision) rev.getStorage(null);
	}
	
	protected void openEditor(IBzrBranch branch, BazaarRevision revision) throws BazaarException {
		IProject[] projects = BzrWorkspaceRoot.findProjectsInBranch(branch);
		openEditor(projects, revision);
	}
	
	protected void openEditor(IResource resource, BazaarRevision revision) throws BazaarException {
		openEditor(new IResource[]{resource}, revision);
	}
	
	protected void openEditor(IBzrBranch branch, BazaarRevision startRevision, BazaarRevision endRevision) throws BazaarException {
		IProject[] projects = BzrWorkspaceRoot.findProjectsInBranch(branch);
		openEditor(projects, startRevision, endRevision);
	}
	
	protected void openEditor(IResource resource, BazaarRevision startRevision, BazaarRevision endRevision) throws BazaarException {
		openEditor(new IResource[]{resource}, startRevision, endRevision);
	}

	protected void openEditor(IResource[] resources, BazaarRevision revision) throws BazaarException {
		CompareUtils.openStructuredCompareEditor(resources,
				getStatus(resources, revision),
				null,
				revision,
				null);
	}
	
	protected void openEditor(IResource[] resources, BazaarRevision startRevision, BazaarRevision endRevision) throws BazaarException {
		CompareUtils.openStructuredCompareEditor(resources,
				getStatus(resources, BazaarRevisionRange.getRange(startRevision, endRevision)),
				endRevision,
				startRevision,
				null);
	}

	public static List<IBzrResourceStatus> getStatus(IResource[] resources, IBazaarRevisionSpec revision) throws BazaarException {
		IBzrLocalResource[] bzrResources = BzrWorkspaceRoot.getBzrResourcesFor(resources);
		StatusCommand cmd = new StatusCommand(bzrResources, revision);
		cmd.run(new NullProgressMonitor());
		return Arrays.asList(cmd.getStatus());
	}
}
