/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Collection;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.commands.BindCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog.LocationDialogInfo;

/**
 * @author Guillermo Gonzalez
 *
 */
public class BindAction extends WorkbenchAction {

	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		// popup a input dialog to get the remote location
		IProject[] projects = getEnclosingProjectsForSelectedResources();
		final IBzrBranch branch = BzrWorkspaceRoot.getBranchFor(projects[0]);
		final LocationDialogInfo dialogInfo = new LocationDialogInfo();
		final BranchLocation remoteLocation = getRemoteLocation(branch, dialogInfo);
		if (remoteLocation != null) {
			run(new WorkspaceModifyOperation() {
				@Override
                public void execute(IProgressMonitor monitor) throws InvocationTargetException {
					try {
						monitor.beginTask(CoreTexts.bind(CoreTexts.BindCommand_taskName,
								new Object[]{branch.getName(), remoteLocation.toString()}), 1000);
						BindCommand cmd = new BindCommand(branch, remoteLocation);
						cmd.run(monitor);
					} catch (BazaarException e) {
						handle(e);
						throw new InvocationTargetException(e);
					} finally {
						monitor.done();
					}
				}
			}, false /* no cancelable */, PROGRESS_DIALOG);
		}
	}

	private BranchLocation getRemoteLocation(IBzrBranch branch, LocationDialogInfo dialogInfo) throws BazaarException {
		Collection<IBzrBranch> locations = getAllBranchLocations(branch);
		IBzrBranch initialBranch = null;
		if (branch instanceof IBzrLocalBranch) {
			initialBranch = ((IBzrLocalBranch) branch).getParent();
		}
		LocationInputDialog dialog = LocationInputDialog.remoteBindLocationDialog(getShell(), locations, initialBranch, dialogInfo);
		dialog.setBlockOnOpen(true);
		if (dialog.open() == LocationInputDialog.OK) {
            try {
				return new BranchLocation(dialogInfo.getLocation());
			} catch (BazaarClientException e) {
			}
		}
		return null;
	}

	@Override
	protected boolean isEnabledByType(IResource resource) {
		if(resource.getType() == IResource.PROJECT) {
			IBzrBranch branch = BzrWorkspaceRoot.getBranchFor((IProject)resource);
			return !branch.isBound();
		}
		return false;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}
}
