/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.resources.IResource;
import org.eclipse.jface.text.ITextSelection;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.team.core.TeamException;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.handlers.HandlerUtil;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;

/**
 * Command handler that wraps CommitAction is needed to be able to provide a shortcut 
 * for an action when the respective command group is disabled in Eclipse 3.6+
 * @see https://bugs.eclipse.org/bugs/show_bug.cgi?id=309074
 * 
 * @author Piotr Piastucki
 */
public class CommitActionHandler extends AbstractHandler {

	public Object execute(final ExecutionEvent event) throws ExecutionException {
		final CommitAction action = new CommitAction();
		action.selectionChanged(null, getSelection(event));
		try {
			if (action.isEnabled()) {
				EclipseBazaarUI.getStandardDisplay().syncExec(new Runnable() {
					public void run() {
						action.run(null);
					}
				});
			}
		} catch (TeamException e) {
		}
		return null;
	}

	private ISelection getSelection(final ExecutionEvent event) throws ExecutionException {
		ISelection selection = HandlerUtil.getCurrentSelectionChecked(event);
		if (selection instanceof ITextSelection) {
			IWorkbenchPage page = HandlerUtil.getActiveWorkbenchWindow(event).getActivePage();
			IEditorInput editorInput = page.getActiveEditor().getEditorInput();
			IResource res = (IResource) editorInput.getAdapter(IResource.class);
			if (res != null) {
				selection = new StructuredSelection(res);
			}
		}
		return selection;
	}

	@Override
	public boolean isEnabled() {
		return true;
	}

}
