/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IResource;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.Dialog;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.eclipse.core.resources.IStorageBazaarRevision;
import org.vcs.bazaar.eclipse.ui.compare.CompareUtils;
import org.vcs.bazaar.eclipse.ui.dialogs.ShowLogDialog;

/**
 * @author Piotr Piastucki
 */
public class CompareWithRevisionAction extends WorkbenchAction {

	@Override
	protected void execute(IAction action) throws Exception {
		IResource[] resources = getSelectedResources();
		if (resources != null && resources.length > 0) {
			ShowLogDialog dialog = new ShowLogDialog(getShell(), resources[0]);
			if (dialog.open() == Dialog.OK && dialog.getSelectedRevision() != null) {
				BazaarRevision revision = dialog.getSelectedRevision();
				if (resources.length == 1 && resources[0] instanceof IFile) {
					CompareUtils.openSaveableEditor(resources[0], new IStorageBazaarRevision(resources[0], revision), getActivePage());
				} else {
					CompareUtils.openStructuredCompareEditor(resources,
							AbstractCompareAction.getStatus(resources, revision),
							null, revision, getActivePage());
				}
			}
		}
	}

	@Override
	protected boolean isEnabledForMultipleResources() {
		return false;
	}

	@Override
	protected boolean isEnabledByType(IResource resource) {
		return resource.getType() == IResource.FILE || resource.getType() == IResource.FOLDER || resource.getType() == IResource.PROJECT;
	}

	@Override
	protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForAddedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForUnmodifiedResources() {
		return true;
	}
}
