/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.jobs.IJobChangeEvent;
import org.eclipse.core.runtime.jobs.IJobStatus;
import org.eclipse.core.runtime.jobs.JobChangeAdapter;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.ui.progress.UIJob;
import org.vcs.bazaar.eclipse.core.utils.BzrJobStatus;
import org.vcs.bazaar.eclipse.ui.actions.CommitAction.CommitableResources;
import org.vcs.bazaar.eclipse.ui.wizards.patch.CreatePatchWizard;

/**
 * @author Piotr Piastucki
 */
public class CreatePatchAction extends WorkbenchAction {

	@Override
	protected void execute(IAction action) throws Exception {
		UIJob job = new UIJob(this.getShell().getDisplay(), "Getting changed resources...") {
			@Override
			public IStatus runInUIThread(IProgressMonitor monitor) {
				monitor.beginTask("Getting changed resources..", 100);
				try {
					CommitableResources resourceStauses = CommitAction.createCommitableResources(monitor, getEnclosingProjectsForSelectedResources());
					CommitableResources selectedResource = CommitAction.createCommitableResources(monitor, getSelectedResources());
					monitor.worked(100);
					if (resourceStauses.getAllStatuses().isEmpty()) {
						return BzrJobStatus.INFO(this, "No differences found");
					}
					List<CommitableResources> results = new ArrayList<CommitableResources>(2);
					results.add(resourceStauses);
					results.add(selectedResource);
					return new BzrJobStatus<List<CommitableResources>>(IJobStatus.OK, this, results, "Changed resources calculated");
				} catch (Exception e) {
					return UIJob.errorStatus(e);
				} finally {
					monitor.done();
				}
			}
		};
		job.setUser(true);
		job.setPriority(UIJob.LONG);
		job.addJobChangeListener(new JobChangeAdapter() {
            @SuppressWarnings("unchecked")
            @Override
            public void done(IJobChangeEvent event) {
				IStatus status = event.getResult();
				if(status instanceof BzrJobStatus) {
					if(status.getSeverity() == IStatus.INFO) {
                        MessageDialog.openInformation(getParentShell(), "Information", status.getMessage());
                    } else if(status.getSeverity() == IStatus.OK) {
						List<CommitableResources> result = ((BzrJobStatus<List<CommitableResources>>)status).getResult();
						CreatePatchWizard wizard = new CreatePatchWizard(result.get(0).getAllStatuses(), result.get(1).getAllStatuses());
						WizardDialog dialog = new WizardDialog(getShell(), wizard);
						dialog.setMinimumPageSize(700, 400);
						dialog.setHelpAvailable(false);
						dialog.open();
					}
				}
				event.getJob().removeJobChangeListener(this);
			}
		});
		job.schedule();
		
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}

}
