/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.util.List;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.core.resources.IStorageBazaarRevision;
import org.vcs.bazaar.eclipse.ui.compare.CompareUtils;


/**
 *
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class DiffAction extends WorkbenchAction {

	public DiffAction() {
		super();
	}

	/**
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 *
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	@Override
    public void execute(IAction action) {
		// TODO: this should be implemented as a compare/replace from repository
		try {
			IResource[] resources = getSelectedResources();
			if (resources != null) {
				if (resources.length == 1 && resources[0] instanceof IFile) {
					CompareUtils.openSaveableEditor(resources[0], new IStorageBazaarRevision(resources[0]), getActivePage());
				} else {
					List<IBzrResourceStatus> commiteableResources = CommitAction.getCommitableResources(
							new NullProgressMonitor(), resources);
					CompareUtils.openStructuredCompareEditor(resources, commiteableResources, null, null, getActivePage());
				}
			}
		} catch(Exception e) {
			MessageDialog.openError(getParentShell(), "An unexpected error ocurred", e.getMessage());
		}
	}

	@Override
	protected boolean isEnabledForMultipleResources() {
		return true;
	}

	@Override
	protected boolean isEnabledByType(IResource resource) {
		return resource.getType() == IResource.FILE || resource.getType() == IResource.FOLDER || resource.getType() == IResource.PROJECT;
	}

	@Override
	protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForAddedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForUnmodifiedResources() {
		return false;
	}
}
