/*******************************************************************************
 * Copyright (c) 2012 Idereal Limited
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Alexander Taler
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import org.eclipse.compare.CompareConfiguration;
import org.eclipse.compare.CompareUI;
import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IFile;
import org.eclipse.jface.action.IAction;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.compare.ConflictingFileEditorInput;

/**
 * @author Alexander Taler
 */
public class EditConflictsAction extends WorkbenchAction {

    @Override
    public void execute(IAction action) throws BazaarException {
        IFile local = (IFile) getSelectedResources()[0];
        runEditConflicts(local);
    }

	public static void runEditConflicts(IFile file) {
		// Find the base, other and this files
        IContainer parent = file.getParent();
        IFile MrgBase = (IFile) parent.findMember(file.getName() + ".BASE");
        IFile MrgOthr = (IFile) parent.findMember(file.getName() + ".OTHER");
        IFile MrgThis = (IFile) parent.findMember(file.getName() + ".THIS");
        if (MrgThis != null && MrgOthr != null) {
	        CompareConfiguration cc = new CompareConfiguration();
	        ConflictingFileEditorInput compare =
	            new ConflictingFileEditorInput(cc, file, MrgThis, MrgOthr, MrgBase);
	        CompareUI.openCompareEditor(compare);
        }
	}

    @Override
    protected boolean isEnabledForUnmanagedResources() {
        return false;
    }

    @Override
    protected boolean isEnabledForManagedResources() {
        return true;
    }

    @Override
    protected boolean isEnabledForAddedResources() {
        return false;
    }

    @Override
    protected boolean isEnabledForMultipleResources() {
        return false;
    }

    @Override
    protected boolean isEnabledForConflictedResources() {
        return true;
    }

    @Override
    protected boolean isEnabledForUnmodifiedResources() {
        return false;
    }

    @Override
    protected boolean isEnabledForModifiedResources() {
        return false;
    }

}
