/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.commands.AddCommand;
import org.vcs.bazaar.eclipse.core.commands.IgnoredCommand;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.dialogs.IgnoredDialog;

/**
 * @authors Javier Der Derian<javierder AT gmail DOT com><br>
 *          Guillermo Gonzalez <guillo.gonzo@gmail.com>
 * @BasedOn RevertAction from BzrEclipse
 *
 * TODO: add support for multiple projects(?)
 */
public class IgnoredAction extends WorkbenchAction {

	/**
	 * <p>
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 * </p>
	 *
	 * @throws BazaarException
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		IProject[] projects = getEnclosingProjectsForSelectedResources();
		// Added IgnoredCommand to get the ignored list
		final IgnoredCommand cmd = new IgnoredCommand(projects[0]);
		final Map<IResource, String> ignored = new HashMap<IResource, String>();

		// Is this necesary to run every command???
		run(new WorkspaceModifyOperation() {
			@Override
            public void execute(IProgressMonitor monitor) throws InvocationTargetException {
				try {
					cmd.run(monitor);
	                ignored.putAll(cmd.getIgnored());
				} catch (BazaarException e) {
					// FIXME: exception handling
					throw new InvocationTargetException(e);
				} finally {
					monitor.done();
				}
			}
		}, false /* no cancelable */, PROGRESS_BUSYCURSOR);
		// If it's null it's because there was a previous error.
		if(ignored != null) {
			IgnoredDialog dialog = new IgnoredDialog(this.getShell(), ignored);

			if(dialog.open() != IgnoredDialog.OK) {
				return;
			}

			final List<IResource> unchecked = dialog.getUnChecked();
			if(unchecked.size() > 0)
			{
				// Changed AddIgnoredCommand for AddCommand
				final AddCommand cmd_add = new AddCommand(BzrWorkspaceRoot.getBzrWorkspaceRootFor(projects[0]), unchecked);
				run(new WorkspaceModifyOperation() {
					@Override
                    public void execute(IProgressMonitor monitor) throws InvocationTargetException {
						try {
							cmd_add.run(monitor);
						} catch (BazaarException e) {
							// FIXME: exception handling
							throw new InvocationTargetException(e);
						} finally {
							monitor.done();
						}
					}
				}, false /* no cancelable */, PROGRESS_DIALOG);
			}
		}



	}

	@Override
    protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForUnmodifiedResources() {
		if(getSelectedProjects().length == 1) {
			return true;
		}
		return false;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return false;
	}
}
