/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.action.IAction;
import org.eclipse.team.ui.TeamUI;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.ui.progress.UIJob;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.model.IBzrResource;
import org.vcs.bazaar.eclipse.core.utils.BzrJobStatus;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.history.BazaarHistoryPageInput;

/**
 * @author Guillermo Gonzalez
 * TODO: Test (split into Operation and Action?)
 */
public class LogAction extends WorkbenchAction {

	/**
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 *
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	@Override
    public void execute(IAction action) {
		// XXX: get only the first element in the selection
		UIJob job = createJob();
		job.setUser(true);
		job.setPriority(UIJob.BUILD);
		job.schedule();
	}

	private UIJob createJob() {
		return new UIJob(this.getShell().getDisplay(), "Fetching revision history") {
			@Override
			public IStatus runInUIThread(IProgressMonitor monitor) {
				monitor.beginTask("fetching...", 100);
				IBzrResource resource; 
				IProject[] selectedProjects = getSelectedProjects();
				if (selectedProjects.length > 1) {
					resource = BzrWorkspaceRoot.getBranchFor(selectedProjects[0]);
				} else {
					resource = BzrWorkspaceRoot.getBzrResourceFor(getSelectedResources()[0]);
				}
				try {
					monitor.subTask("fetching resource revisions");
					monitor.worked(20);
					TeamUI.getHistoryView().showHistoryFor(new BazaarHistoryPageInput(resource, getSelectedResources()));
					return BzrJobStatus.OK_STATUS;
				} catch (Exception e) {
					EclipseBazaarUI.log(e.getMessage(), e);
					return UIJob.errorStatus(e);
				} finally {
					monitor.done();
				}
			}
		};
	}

	@Override
	protected boolean isEnabledForMultipleResources() {
		return true;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}

	@Override
	protected boolean isEnabledForMultipleProjectsOnly() {
		return true;
	}

	@Override
	protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForAddedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledByType(IResource resource) {
		return resource.getType() == IResource.FILE || resource.getType() == IResource.PROJECT || resource.getType() == IResource.FOLDER;
	}
}
