/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Collection;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.MergeCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.dialogs.MergeDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.MergeDialog.MergeDialogInfo;

/**
 * @author Guillermo Gonzalez
 *
 */
public class MergeAction extends WorkbenchAction {

	@Override
	protected void execute(IAction anAction) throws BazaarException, InvocationTargetException, InterruptedException {
		// popup a input dialog to get the remote location
		final IProject[] projects = getEnclosingProjectsForSelectedResources();
		final IBzrBranch branch = BzrWorkspaceRoot.getBranchFor(projects[0]);
		final MergeDialogInfo dialogInfo = new MergeDialogInfo();
		final BranchLocation remoteLocation = getRemoteLocation(branch, dialogInfo);
		if (remoteLocation != null) {
	        String message = null;
			try {
				run(new WorkspaceModifyOperation() {
					@Override
	                public void execute(IProgressMonitor monitor) throws InvocationTargetException, BazaarException {
						try {
							monitor.beginTask("", 1000); //$NON-NLS-1$
							monitor.setTaskName(CoreTexts.MergeCommand_taskName); //FIXME //$NON-NLS-1$
							// only enabled for one project at a time
							MergeCommand cmd = new MergeCommand(branch, remoteLocation, dialogInfo.getOptions().toArray(new Option[0]));
							cmd.run(EclipseBazaarCore.subProgressMonitorFor(monitor));
						} finally {
							monitor.done();
						}
					}
				}, false /* no cancelable */, PROGRESS_DIALOG);
	        } catch (InvocationTargetException e) {
	        	message = handleConflicts(e);
			}
	        if (message != null) {
	            MessageDialog.openInformation(getShell(), UITexts.Dialog_informationTitle, message);
	        }
		}
	}

	private BranchLocation getRemoteLocation(IBzrBranch branch, MergeDialogInfo dialogInfo) throws BazaarException {
		Collection<IBzrBranch> locations = getAllBranchLocations(branch);
		IBzrBranch initialBranch = null;
		if (branch instanceof IBzrLocalBranch) {
			initialBranch = ((IBzrLocalBranch) branch).getParent();
		}
		MergeDialog dialog = new MergeDialog(getShell(), locations, initialBranch, dialogInfo);
		dialog.setBlockOnOpen(true);
		if (dialog.open() == MergeDialog.OK) {
            try {
				return new BranchLocation(dialogInfo.getLocation());
			} catch (BazaarClientException e) {
			}
		}
		return null;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}

}
