/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Collection;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.PullCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog.LocationDialogInfo;

/**
 * @author Guillermo Gonzalez
 *
 */
public class PullAction extends WorkbenchAction {

	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		// popup a input dialog to get the remote location
		final IProject[] projects = getEnclosingProjectsForSelectedResources();
		final IBzrBranch branch = BzrWorkspaceRoot.getBranchFor(projects[0]);
		final LocationDialogInfo dialogInfo = getRemoteLocation(branch);
		if (dialogInfo != null && dialogInfo.getLocation() != null && !"".equals(dialogInfo.getLocation().trim())) {
	        String message = null;
            try {
            	final BranchLocation remoteLocation = new BranchLocation(dialogInfo.getLocation());
            	/*FIXME: extract to PullOperation */
				run(new WorkspaceModifyOperation() {
					@Override
	                public void execute(IProgressMonitor monitor) throws InvocationTargetException, BazaarException {
						try {
							monitor.beginTask("", 1000); //$NON-NLS-1$
							monitor.setTaskName(CoreTexts.bind(CoreTexts.PullCommand_taskName, remoteLocation.toString())); //$NON-NLS-1$
							// only enabled for one project at a time
							PullCommand cmd = new PullCommand(branch, remoteLocation);
							cmd.setRemember(dialogInfo.isRemember());
							cmd.setOverwrite(dialogInfo.isOverwrite());
							cmd.run(EclipseBazaarCore.subProgressMonitorFor(monitor));
						} finally {
							monitor.done();
						}
					}
				}, false /* no cancelable */, PROGRESS_DIALOG);
            } catch (InvocationTargetException ite) {
            	message = handleConflicts(ite);
            } catch (BazaarClientException e) {
				EclipseBazaarUI.log(e.getMessage(), e);
				throw new InvocationTargetException(e, e.getMessage());
            }
	        if (message != null) {
	            MessageDialog.openInformation(getShell(), UITexts.Dialog_informationTitle, message);
	        }
		}
	}

	private LocationDialogInfo getRemoteLocation(IBzrBranch branch) throws BazaarException {
		final LocationDialogInfo dialogInfo = new LocationDialogInfo();
		Collection<IBzrBranch> locations = getAllBranchLocations(branch);
		IBzrBranch initialBranch = null;
		if (branch instanceof IBzrLocalBranch) {
			initialBranch = ((IBzrLocalBranch) branch).getParent();
		}
		LocationInputDialog dialog = LocationInputDialog.remotePullLocationDialog(getShell(), locations, initialBranch, dialogInfo);
		dialog.setBlockOnOpen(true);
		if (dialog.open() == LocationInputDialog.OK) {
			return dialogInfo;
		}
		return null;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}

}
