/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Collection;

import org.eclipse.core.resources.IProject;
import org.eclipse.jface.action.IAction;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog.LocationDialogInfo;
import org.vcs.bazaar.eclipse.ui.operations.PushOperation;

/**
 * @author Guillermo Gonzalez
 *
 */
public class PushAction extends WorkbenchAction {


	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		// popup a input dialog to get the remote location
		IProject[] projects = getEnclosingProjectsForSelectedResources();
		execute(BzrWorkspaceRoot.getBranchFor(projects[0]));
	}

	protected void execute(final IBzrBranch branch) throws InvocationTargetException, InterruptedException, BazaarException {
		final LocationDialogInfo dialogInfo = getRemoteLocation(branch);
		if (dialogInfo != null && dialogInfo.getLocation() != null && !dialogInfo.getLocation().trim().isEmpty()) {
        	try {
				final BranchLocation remoteLocation = new BranchLocation(dialogInfo.getLocation());
				new PushOperation(getTargetPart(), branch, remoteLocation, dialogInfo.isRemember(), dialogInfo.isOverwrite(), dialogInfo.isUseExistingDir()).run();
			} catch (BazaarClientException e) {
				EclipseBazaarUI.log(e.getMessage(), e);
				throw new InvocationTargetException(e, e.getMessage());
			}
		}
	}

	private LocationDialogInfo getRemoteLocation(IBzrBranch branch) {
		final LocationDialogInfo dialogInfo = new LocationDialogInfo();
		try {
			Collection<IBzrBranch> locations = getAllBranchLocations(branch);
			IBzrBranch initialBranch = null;
			if (branch instanceof IBzrLocalBranch) {
				initialBranch = ((IBzrLocalBranch) branch).getPushBranch();
			}
			LocationInputDialog dialog = LocationInputDialog.remotePushLocationDialog(getShell(), locations, initialBranch, dialogInfo);
			dialog.setBlockOnOpen(true);
			if (dialog.open() == LocationInputDialog.OK) {
				return dialogInfo;
			}

		} catch (Exception ex) {
			// this is an unexpected exception (ok, no so unexpected ;), but is for sure a bug)
			handle(ex);
		}
		return null;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}

}
