/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Arrays;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.commandline.syntax.IRevertOptions;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.commands.RevertCommand;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.dialogs.ShowLogDialog;

/**
 * @author Piotr Piastucki
 */
public class ReplaceWithRevisionAction extends WorkbenchAction {

	@Override
	protected void execute(IAction action) throws Exception {
		IResource[] resources = getSelectedResources();
		ShowLogDialog dialog = new ShowLogDialog(getShell(), resources[0]);
		if (dialog.open() == Dialog.OK && dialog.getSelectedRevision() != null) {
			BazaarRevision revision = dialog.getSelectedRevision();
			revertChanges(new Option[]{IRevertOptions.NO_BACKUP, IRevertOptions.REVISION.with(revision.toString())});
		}
	}

	protected void revertChanges(Option[] options) throws InvocationTargetException, InterruptedException {
		IBzrLocalResource[] resources = BzrWorkspaceRoot.getBzrResourcesFor(getSelectedResources());
		final RevertCommand cmd = new RevertCommand(Arrays.asList(resources), false, options);
		run(new WorkspaceModifyOperation() {
			@Override
            public void execute(IProgressMonitor monitor) throws InvocationTargetException {
				try {
					cmd.run(monitor);
				} catch (BazaarException e) {
					throw new InvocationTargetException(e);
				} finally {
					monitor.done();
				}
			}
		}, false /* no cancelable */, PROGRESS_DIALOG);
	}

	@Override
	protected boolean isEnabledForMultipleResources() {
		return true;
	}

	@Override
	protected boolean isEnabledByType(IResource resource) {
		return resource.getType() == IResource.FILE || resource.getType() == IResource.FOLDER || resource.getType() == IResource.PROJECT;
	}

	@Override
	protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForAddedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForUnmodifiedResources() {
		return true;
	}
}
