/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.ResolveCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 *
 */
public class ResolveAction extends WorkbenchAction {

	protected Option[] getOptions() {
		return new Option[0];
	}

	public static void runResolve(IProgressMonitor monitor, IResource[] selectedResources, Option... options)
			throws InvocationTargetException {
		try {
			Map<IBzrBranch, List<IResource>> map = getFilesByBranchMap(selectedResources);
			Set<IBzrBranch> keySet = map.keySet();
			monitor.beginTask("Resolving conflicts", keySet.size() * 1000); //$NON-NLS-1$
			for (IBzrBranch branch : keySet) {
				List<IResource> resources = map.get(branch);
				ResolveCommand cmd = new ResolveCommand(resources, options);
				cmd.run(EclipseBazaarCore.subProgressMonitorFor(monitor));
			}
		} catch (BazaarException e) {
			EclipseBazaarUI.log(e);
			throw new InvocationTargetException(e);
		} finally {
			monitor.done();
		}
	}
	
	@Override
    protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		run(new WorkspaceModifyOperation() {

			@Override
			protected void execute(IProgressMonitor monitor) throws CoreException, InvocationTargetException, InterruptedException {
				runResolve(monitor, getSelectedResources(), getOptions());
			}

		}, false /* no cancelable */, PROGRESS_DIALOG);
	}

	@Override
	protected boolean isEnabledForManagedResources() {
		return true;
	}

	@Override
	protected boolean isEnabledForAddedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForMultipleResources() {
		return true;
	}

	@Override
	protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForConflictedResources() {
		return true;
	}

	@Override
	protected boolean isEnabledForUnmodifiedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForModifiedResources() {
		return false;
	}

}
