/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.commands.RevertCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.dialogs.RevertDialog;

/**
 * @author Guillermo Gonzalez <guillo DOT gonzo AT gmail DOT com>
 */
public class RevertAction extends WorkbenchAction {

	/**
	 * <p>
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 * </p>
	 *
	 * @throws BazaarException
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		IProject[] projects = getEnclosingProjectsForSelectedResources();
		List<IBzrResourceStatus> selectedResources = CommitAction.getCommitableResources(new NullProgressMonitor(), getSelectedResources());
		List<IBzrResourceStatus> commiteableResources = CommitAction.getCommitableResources(new NullProgressMonitor(), projects);
		RevertDialog dialog = new RevertDialog(this.getShell(), commiteableResources, selectedResources);
		dialog.setWholeBranchEnabled(true);
		if(dialog.open() != RevertDialog.OK || (dialog.getSelection().size() == 0 && !dialog.isWholeBranch())) {
			return;
		}
		final List<IBzrLocalResource> resourcesToRevert = new ArrayList<IBzrLocalResource>();
		if(dialog.isWholeBranch()) {
			// ignore the selection the revert applies to the whole branch
			resourcesToRevert.addAll(Arrays.asList(BzrWorkspaceRoot.getBzrResourcesFor(projects)));
		} else {
			for (IBzrResourceStatus bzrResourceStatus : dialog.getSelection()) {
				resourcesToRevert.add(bzrResourceStatus.getResource());
			}
		}
		final RevertCommand cmd = new RevertCommand(resourcesToRevert, dialog.isWholeBranch(), dialog.getOptions());
		run(new WorkspaceModifyOperation() {
			@Override
            public void execute(IProgressMonitor monitor) throws InvocationTargetException {
				try {
					cmd.run(monitor);
				} catch (BazaarException e) {
					// FIXME: exception handling
					throw new InvocationTargetException(e);
				} finally {
					monitor.done();
				}
			}
		}, false /* no cancelable */, PROGRESS_DIALOG);
	}

	@Override
    protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForUnmodifiedResources() {
		if (getSelectedProjects().length > 0) {
			return true;
		}
		return false;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}
}
