/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Collection;

import org.eclipse.core.resources.IProject;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.vcs.bazaar.client.IBazaarInfo;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.core.repository.BranchFactory;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.internal.core.model.LocalBranch;
import org.vcs.bazaar.eclipse.ui.dialogs.SendDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.SendDialog.SendDialogInfo;
import org.vcs.bazaar.eclipse.ui.operations.SendOperation;

/**
 * @author Javier Der Derian<javierder AT gmail DOT com>
 * @BasedOn RevertAction from BzrEclipse
 */
public class SendAction extends WorkbenchAction {

	/**
	 * <p>
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 * </p>
	 *
	 * @throws BazaarException
	 * @throws BazaarClientException 
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException, BazaarClientException {
		IProject[] projects = getEnclosingProjectsForSelectedResources();
		IBzrBranch branch = BzrWorkspaceRoot.getBranchFor(projects[0]);
		Collection<IBzrBranch> locations = getAllBranchLocations(branch);
		IBzrBranch initialBranch = null;
		if (branch instanceof LocalBranch) {
			IBazaarInfo info = ((LocalBranch) branch).getInfo();
			if (info.getRelatedBranches() != null && info.getRelatedBranches().getSubmitBranch() != null) {
				initialBranch = BranchFactory.findOrCreateFor(info.getRelatedBranches().getSubmitBranch());
			}
		}

		SendDialog dialog = new SendDialog(this.getShell(), locations, initialBranch, new SendDialogInfo());

		if(dialog.open() != SendDialog.OK) {
			return;
		}

		final IBzrLocalResource[] resourcesToSend = BzrWorkspaceRoot.getBzrResourcesFor(projects);
		new SendOperation(getTargetPart(), resourcesToSend[0], dialog.getOptions(), new BranchLocation(dialog.getValue())).run();

	}

	@Override
    protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}
}
