/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Collection;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.commands.SwitchCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog.LocationDialogInfo;

/**
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class SwitchAction extends WorkbenchAction {

	@Override
    protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		IProject[] projects = getEnclosingProjectsForSelectedResources();
		final IBzrBranch branch = BzrWorkspaceRoot.getBranchFor(projects[0]);
		final LocationDialogInfo dialogInfo = new LocationDialogInfo();
		// popup a input dialog to get the remote location
		final BranchLocation remoteLocation = getRemoteLocation(branch, dialogInfo);
		if (remoteLocation != null) {
			run(new IRunnableWithProgress() {
				public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
					try {
						SwitchCommand cmd = new SwitchCommand(branch, remoteLocation);
						cmd.setForce(dialogInfo.isForce());
						cmd.setCreateBranch(dialogInfo.isCreateBranch());
						cmd.run(monitor);
					} catch (BazaarException e) {
						throw new InvocationTargetException(e);
					} finally {
					}
				}
			}, "Cannot switch a branch, only a checkout.", PROGRESS_DIALOG);
		}
	}

	private BranchLocation getRemoteLocation(IBzrBranch branch, LocationDialogInfo dialogInfo) throws BazaarException {
		Collection<IBzrBranch> locations = getAllBranchLocations(branch);
		LocationInputDialog dialog = LocationInputDialog.switchLocationDialog(getShell(), locations, dialogInfo);
		dialog.setBlockOnOpen(true);
		if (dialog.open() == LocationInputDialog.OK) {
            try {
				return new BranchLocation(dialogInfo.getLocation());
			} catch (BazaarClientException e) {
			}
		}
		return null;
	}

	@Override
	protected boolean isEnabledByType(IResource resource) {
		if(resource.getType() == IResource.PROJECT) {
			BzrWorkspaceRoot root = BzrWorkspaceRoot.getBzrWorkspaceRootFor((IProject)resource);
			return root.getBranch().isBound();
		}
		return false;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}

}
