/*******************************************************************************
* Copyright (c) 2013 Piotr Piastucki
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.mapping.RemoteResourceMappingContext;
import org.eclipse.core.resources.mapping.ResourceMapping;
import org.eclipse.jface.action.IAction;
import org.eclipse.team.core.subscribers.SubscriberScopeManager;
import org.eclipse.team.ui.TeamUI;
import org.eclipse.team.ui.synchronize.ISynchronizeParticipant;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.ide.ResourceUtil;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalBranch;
import org.vcs.bazaar.eclipse.core.synchronize.BazaarResourceVariantTreeSubscriber;
import org.vcs.bazaar.eclipse.core.synchronize.BazaarSubscriberMergeContext;
import org.vcs.bazaar.eclipse.core.synchronize.BazaarSubscriberResourceMappingContext;
import org.vcs.bazaar.eclipse.core.synchronize.BazaarSynchronizeData;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog.LocationDialogInfo;
import org.vcs.bazaar.eclipse.ui.synchronize.BazaarModelSynchronizeParticipant;

public class SynchronizeAction extends WorkbenchAction {

	private static ResourceMapping[] getResourceMappings(IResource[] elements) {
		List<ResourceMapping> mappings = new ArrayList<ResourceMapping>();
		for (IResource element : elements) {
			ResourceMapping mapping = ResourceUtil.getResourceMapping(element);
			if (mapping != null && org.vcs.bazaar.eclipse.core.utils.ResourceUtil.shouldHandle(element))
				mappings.add(mapping);
		}
		return mappings.toArray(new ResourceMapping[mappings.size()]);
	}

	@Override
	protected void execute(IAction action) throws Exception {
		IResource[] resources = getSelectedResources();
		IProject[] projects = this.getEnclosingProjectsForSelectedResources();
		final IBzrBranch branch = BzrWorkspaceRoot.getBranchFor(projects[0]);
		LocationDialogInfo dialogInfo = getRemoteLocation(branch);
		if (dialogInfo != null && dialogInfo.getLocation() != null && !dialogInfo.getLocation().trim().isEmpty()) {
        	final BranchLocation remoteLocation = new BranchLocation(dialogInfo.getLocation());
			BazaarSynchronizeData syncData = new BazaarSynchronizeData(resources, remoteLocation);
			final BazaarResourceVariantTreeSubscriber subscriber = new BazaarResourceVariantTreeSubscriber(syncData);
			RemoteResourceMappingContext remoteContext = new BazaarSubscriberResourceMappingContext(subscriber);
			ResourceMapping[] mappings = getResourceMappings(resources);
			SubscriberScopeManager manager = new SubscriberScopeManager(subscriber.getName(), mappings, subscriber, remoteContext, true);
			BazaarSubscriberMergeContext context = new BazaarSubscriberMergeContext(subscriber, manager, syncData);
			final BazaarModelSynchronizeParticipant participant = new BazaarModelSynchronizeParticipant(context);
			TeamUI.getSynchronizeManager().addSynchronizeParticipants(new ISynchronizeParticipant[] { participant });
			IWorkbenchPart activePart = null;
			if (window != null) {
				activePart = window.getActivePage().getActivePart();
			}
			participant.run(activePart);
		}
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}

	private LocationDialogInfo getRemoteLocation(IBzrBranch branch) throws BazaarException {
		final LocationDialogInfo dialogInfo = new LocationDialogInfo();
		Collection<IBzrBranch> locations = getAllBranchLocations(branch);
		IBzrBranch initialBranch = null;
		if (branch instanceof IBzrLocalBranch) {
			initialBranch = ((IBzrLocalBranch) branch).getParent();
		}
		LocationInputDialog dialog = LocationInputDialog.remoteLocationDialog(getShell(), locations, initialBranch, dialogInfo, "Please enter the URI to synchronize with");
		dialog.setBlockOnOpen(true);
		if (dialog.open() == LocationInputDialog.OK) {
			return dialogInfo;
		}
		return null;
	}
	
}
