/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.TagCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.dialogs.TagDialog;

/**
 * @author Piotr Piastucki
 */
public class TagAction extends WorkbenchAction {

	@Override
	protected void execute(IAction action) throws Exception {
		final IProject[] projects = getEnclosingProjectsForSelectedResources();
		final IBzrBranch branch = BzrWorkspaceRoot.getBranchFor(projects[0]);
		final TagDialog dialog = new TagDialog(getShell(), branch);
		if (dialog.open() == TagDialog.OK) {
			run(new WorkspaceModifyOperation() {
				@Override
	            public void execute(IProgressMonitor monitor) throws InvocationTargetException {
					try {
						monitor.beginTask(CoreTexts.bind(CoreTexts.TagCommand_taskName, branch.getName()), 1000);
						TagCommand cmd = new TagCommand(branch, dialog.getTagName(), dialog.getOptions());
						cmd.run(EclipseBazaarCore.subProgressMonitorFor(monitor));
					} catch (BazaarException e) {
						handle(e);
						throw new InvocationTargetException(e);
					} finally {
						monitor.done();
					}
				}
			}, false /* no cancelable */, PROGRESS_DIALOG);
		}
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}
}
