/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.commands.UnBindCommand;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 *
 */
public class UnBindAction extends WorkbenchAction {

	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		final IProject project = getSelectedProjects()[0];
		run(new WorkspaceModifyOperation() {
			@Override
            public void execute(IProgressMonitor monitor) throws InvocationTargetException {
				try {
					monitor.beginTask(CoreTexts.bind(CoreTexts.UnBindCommand_taskName, project.getName()), 100);
					UnBindCommand cmd = new UnBindCommand(BzrWorkspaceRoot.getBranchFor(project));
					cmd.run(monitor);
				} catch (BazaarException e) {
					throw new InvocationTargetException(e);
				} finally {
					monitor.done();
				}
			}
		}, false /* no cancelable */, PROGRESS_DIALOG);
	}

	@Override
	protected boolean isEnabledByType(IResource resource) {
		if(resource.getType() == IResource.PROJECT) {
			BzrWorkspaceRoot root = BzrWorkspaceRoot.getBzrWorkspaceRootFor((IProject)resource);
			return root.getBranch().isBound();
		}
		return false;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}
}
