/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.commands.UpdateCommand;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.UITexts;

/**
 *
 * @author Guillermo Gonzalez
 *
 */
public class UpdateAction extends WorkbenchAction {

	/**
	 * <p>
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 * </p>
	 *
	 * @throws BazaarException
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		IProject project = getSelectedProjects()[0];
		final UpdateCommand cmd = new UpdateCommand(BzrWorkspaceRoot.getBranchFor(project));
        String message = null;
        try {
            run(new WorkspaceModifyOperation() {
                @Override
                public void execute(IProgressMonitor monitor)
                    throws InvocationTargetException, BazaarException
                {
                    try {
                        cmd.run(monitor);
                    } finally {
                        monitor.done();
                    }
                }
            }, false /* no cancelable */, PROGRESS_DIALOG);
        } catch (InvocationTargetException ite) {
        	message = handleConflicts(ite);
        }
        if (message != null) {
            MessageDialog.openInformation(getShell(), UITexts.Dialog_informationTitle, message);
        }
	}

	@Override
	protected boolean isEnabledByType(IResource resource) {
		if (resource.getType() == IResource.PROJECT) {
			BzrWorkspaceRoot root = BzrWorkspaceRoot.getBzrWorkspaceRootFor((IProject)resource);
			return root.getBranch().isBound();
		}
		return false;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}

}
