/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.ui.compare;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.compare.CompareConfiguration;
import org.eclipse.compare.CompareEditorInput;
import org.eclipse.compare.ResourceNode;
import org.eclipse.compare.structuremergeviewer.Differencer;
import org.eclipse.core.runtime.IProgressMonitor;

/**
 * Read only compare editor input
 *
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class BazaarCompareEditorInput extends CompareEditorInput {

	private static final Differencer DIFFERENCER = new Differencer();
	private ResourceNode left;
	private ResourceNode right;

	/**
	 * This constructor use a default configuration with both side read-only
	 * @param resource
	 * @param left
	 * @param right
	 */
	public BazaarCompareEditorInput(ResourceNode left, ResourceNode right) {
		this(new CompareConfiguration(), left, right);
		getCompareConfiguration().setLeftEditable(false);
		getCompareConfiguration().setRightEditable(false);
	}

	private BazaarCompareEditorInput(CompareConfiguration configuration,
			ResourceNode left, ResourceNode right) {
		super(configuration);
		this.left = left;
		this.right = right;
		CompareEditorUtil.setLabels(this, left, right, null, null);
	}

	@Override
	protected Object prepareInput(IProgressMonitor monitor)
			throws InvocationTargetException, InterruptedException {
		return DIFFERENCER.findDifferences(false, monitor, null, null, left, right);
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == this) {
			return true;
		}
		if (obj instanceof BazaarCompareEditorInput) {
			BazaarCompareEditorInput other = (BazaarCompareEditorInput) obj;
			boolean eq = left != null ? left.equals(other.left) : other.left == null;
			if (eq) {
				eq = right != null ? right.equals(other.right) : other.right == null;
			}
			return eq;
		}
		return false;
	}
}
