/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.ui.compare;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.compare.IStreamContentAccessor;
import org.eclipse.compare.ITypedElement;
import org.eclipse.compare.ResourceNode;
import org.eclipse.core.resources.IResource;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;

/**
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class BazaarResourceNode extends ResourceNode implements IStreamContentAccessor, ITypedElement {

	private List<BazaarResourceNode> children = new ArrayList<BazaarResourceNode>();
	
	public BazaarResourceNode(IBzrLocalResource resource) {
		super(resource.getIResource());
	}

	public BazaarResourceNode(IResource resource) {
		super(resource);
	}

	@Override
	public Object[] getChildren() {
		return children.toArray(new ITypedElement[children.size()]);
	}

	public void addChild(BazaarResourceNode node) {
		children.add(node);
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == this) {
			return true;
		}
		if (super.equals(obj)) {
			if (obj instanceof ResourceNode) {
				if (getResource() == null) {
					return ((ResourceNode) obj).getResource() == null;
				}
				return getResource().equals(((ResourceNode) obj).getResource());
			}
		}
		return false;
	}
}
