/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.compare;

import org.eclipse.compare.CompareConfiguration;
import org.eclipse.compare.CompareEditorInput;
import org.eclipse.compare.IResourceProvider;
import org.eclipse.compare.ITypedElement;
import org.eclipse.core.resources.IResource;
import org.eclipse.team.core.history.IFileRevision;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.eclipse.ui.UITexts;


/**
 * @author Piotr Piastucki
 */
public class CompareEditorUtil {

	static IFileRevision getRevision(ITypedElement left) {
		if (left instanceof IFileRevision) {
			return (IFileRevision) left;
		}
		return null;
	}

	static String formatRevision(BazaarRevision revision) {
		StringBuilder sb = new StringBuilder();
		sb.append(revision.toString());
		return sb.toString();
	}
	
	static String getRevisionName(ITypedElement element, BazaarRevision revision) {
		if (revision != null) {
			return formatRevision(revision);
		} else if (getRevision(element) != null) {
			return getRevision(element).getName();
		} else if (element instanceof BazaarRevisionNode) {
			return formatRevision(((BazaarRevisionNode)element).getRevision());
		}
		return null;
	}
	
	static IResource getResource(ITypedElement left) {
		if (left instanceof IResourceProvider) {
			IResourceProvider resourceProvider = (IResourceProvider) left;
			return resourceProvider.getResource();
		}
		return null;
	}
	
	static String getResourceName(ITypedElement left, ITypedElement right) {
		IResource resource = getResource(left);
		if (resource == null) {
			resource = getResource(right);
		}
		if (resource != null) {
			return resource.getName();
		}
		return left != null ? left.getName() : right.getName();
	}

	static void setLabels(CompareEditorInput compareEditorInput, 
						    ITypedElement left, ITypedElement right, 
						    BazaarRevision leftRevision, BazaarRevision rightRevision) {
		
		String leftRevisionName = getRevisionName(left, leftRevision);
		String rightRevisionName = getRevisionName(right, rightRevision);
		String resourceName = getResourceName(left, right);
		if (leftRevisionName == null) {
			leftRevisionName = UITexts.CompareWith_workspace;
		}
		if (rightRevisionName == null) {
			rightRevisionName = UITexts.CompareWith_latest;
		}
		String title = UITexts.bind(UITexts.CompareWith_title, new String[]{resourceName, leftRevisionName, rightRevisionName}); 
		String leftLabel = UITexts.bind("{0}", new String[]{leftRevisionName}); 
		String rightLabel = UITexts.bind("{0}", new String[]{rightRevisionName});
		CompareConfiguration cc = compareEditorInput.getCompareConfiguration();
		compareEditorInput.setTitle(title);
		cc.setLeftLabel(leftLabel);
		cc.setRightLabel(rightLabel);
	}

}
