/*******************************************************************************
* Copyright (c) 2007-2011 Guillermo Gonzalez
* Copyright (c) 2007-2013 Piotr Piastucki
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.ui.compare;

import java.util.List;

import org.eclipse.compare.CompareEditorInput;
import org.eclipse.compare.CompareUI;
import org.eclipse.core.resources.IResource;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IEditorReference;
import org.eclipse.ui.IReusableEditor;
import org.eclipse.ui.IWorkbenchPage;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.core.resources.IStorageBazaarRevision;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;

/**
 *
 * @author Piotr Piastucki
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class CompareUtils {

	public static void openDialog(IResource file) {
		CompareEditorInput editorInput = getEditorInput(new BazaarResourceNode(file), getNode(file, new IStorageBazaarRevision(file)));
		CompareUI.openCompareDialog(editorInput);
	}

	public static void openEditor(IResource resource, IStorageBazaarRevision left, IStorageBazaarRevision right) {
		CompareEditorInput editorInput = getEditorInput(getNode(resource, left), getNode(resource, right));
		openOrReuseCompareEditor(null, editorInput);
	}

	public static void openSaveableEditor(IResource left, IStorageBazaarRevision right, IWorkbenchPage page) {
		CompareEditorInput editorInput = new SaveableBazaarCompareEditorInput(new BazaarResourceNode(left), getNode(left, right), page);
		openOrReuseCompareEditor(page, editorInput);
	}

	private static CompareEditorInput getEditorInput(BazaarResourceNode left, BazaarResourceNode right) {
		return new BazaarCompareEditorInput(left, right);
	}

	private static BazaarRevisionNode getNode(IResource resource, IStorageBazaarRevision rev) {
		return rev == null ? null : new BazaarRevisionNode(resource, rev);
	}

	public static void openStructuredCompareEditor(IResource[] resources, List<IBzrResourceStatus> localResources,
			BazaarRevision leftRevision, BazaarRevision rightRevision, IWorkbenchPage activePage) {
		CompareEditorInput editorInput = new BazaarStatusBasedCompareEditorInput(resources, localResources, leftRevision, rightRevision, activePage);
		openOrReuseCompareEditor(activePage, editorInput);
	}

	private static void openOrReuseCompareEditor(IWorkbenchPage activePage, CompareEditorInput editorInput) {
		if (activePage == null) {
			activePage = EclipseBazaarUI.getActivePage();
		}
		IReusableEditor editor = findReusableCompareEditor(editorInput, activePage);
		if (editor != null) {
			CompareUI.reuseCompareEditor(editorInput, editor);
			activePage.activate(editor);
		} else {
			CompareUI.openCompareEditorOnPage(editorInput, activePage);
		}
	}

	public static IReusableEditor findReusableCompareEditor(CompareEditorInput input, IWorkbenchPage page) {
		IEditorReference[] editorRefs = page.getEditorReferences();
		for (int i = 0; i < editorRefs.length; i++) {
			IEditorPart part = editorRefs[i].getEditor(false);
			if (part != null && part instanceof IReusableEditor) {
				if (input.equals(part.getEditorInput())) {
					return (IReusableEditor)part;
				}
			}
		}
		return null;
	}

}
