/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.compare;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.compare.CompareConfiguration;
import org.eclipse.compare.IEditableContent;
import org.eclipse.compare.ITypedElement;
import org.eclipse.compare.ResourceNode;
import org.eclipse.compare.structuremergeviewer.DiffNode;
import org.eclipse.compare.structuremergeviewer.ICompareInput;
import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.team.ui.synchronize.SaveableCompareEditorInput;
import org.eclipse.ui.IWorkbenchPage;

/**
 * Compare editor input that is able to save the left side of the compare
 *
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class SaveableBazaarCompareEditorInput extends SaveableCompareEditorInput {

	private static class MyDiffNode extends DiffNode {

		private String name;
		
		public MyDiffNode(int kind, ITypedElement left, ITypedElement right) {
			super(kind, null, left, right);
		}

		public MyDiffNode(ITypedElement left, ResourceNode right) {
			super(left, right);
		}

		@Override
		protected void fireChange() {
			super.fireChange();
		}
		
		@Override
		public String getName() {
			return name;
		}
		
		public void setName(String name) {
			this.name = name;
		}
	}

	private ResourceNode left;
	private ResourceNode right;

	public SaveableBazaarCompareEditorInput(ResourceNode left, ResourceNode right, IWorkbenchPage page) {
		super(new CompareConfiguration(), page);
		this.left = left;
		this.right = right;
	}

	@Override
	protected void fireInputChange() {
		((MyDiffNode)getCompareInput()).fireChange();
	}

	@Override
	protected ICompareInput prepareCompareInput(IProgressMonitor monitor)
			throws InvocationTargetException, InterruptedException {
		ITypedElement leftfile = createFileElement((IFile)left.getResource());
		MyDiffNode input = new MyDiffNode(leftfile, right);
		getCompareConfiguration().setLeftEditable(isLeftEditable(input));
		getCompareConfiguration().setRightEditable(false);
		CompareEditorUtil.setLabels(this, left, right, null, null);
		input.setName(getTitle());
		return input;
	}

	private boolean isLeftEditable(ICompareInput input) {
		Object left = input.getLeft();
		if (left instanceof IEditableContent) {
			return ((IEditableContent) left).isEditable();
		}
		return false;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == this) {
			return true;
		}
		if (obj instanceof SaveableBazaarCompareEditorInput) {
			SaveableBazaarCompareEditorInput other = (SaveableBazaarCompareEditorInput) obj;
			boolean eq = left != null ? left.equals(other.left) : other.left == null;
			if (eq) {
				eq = right != null ? right.equals(other.right) : other.right == null;
			}
			return eq;
		}
		return false;
	}

}
