/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.credentials;

import java.util.concurrent.atomic.AtomicReference;

import org.eclipse.swt.widgets.Shell;
import org.vcs.bazaar.client.IBazaarPromptUserPassword;
import org.vcs.bazaar.client.IBazaarUserPassword;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.credentials.BazaarCredentials;
import org.vcs.bazaar.eclipse.core.credentials.SecureCredentialsStoreException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.dialogs.LoginDialog;

/**
 * @author Piotr Piastucki
 */
public class BazaarCredentialsProvider implements IBazaarPromptUserPassword {

	public IBazaarUserPassword getCredentials(final String location, final boolean passwordOnly, final boolean changeStored) {
		if (!changeStored) {
			BazaarCredentials credentials = null;
			try {
				credentials = EclipseBazaarCore.getDefault().getSecureCredentialsStore().getCredentials(location);
			} catch (SecureCredentialsStoreException e) {
			}
			if (credentials != null && credentials.getPassword() != null && (passwordOnly || credentials.getUser() != null)) {
				return credentials;
			}
		}
		final AtomicReference<IBazaarUserPassword> aRef = new AtomicReference<IBazaarUserPassword>(null);
		EclipseBazaarUI.getDefault().getWorkbench().getDisplay().syncExec(new Runnable() {
			public void run() {
				Shell shell = EclipseBazaarUI.getDefault().getWorkbench().getActiveWorkbenchWindow().getShell();
				LoginDialog dialog = new LoginDialog(shell, location, passwordOnly);
				if (dialog.open() == LoginDialog.OK) {
					BazaarCredentials credentials = dialog.getCredentials();
					if (credentials != null && dialog.getStoreInSecureStore()) {
						try {
							EclipseBazaarCore.getDefault().getSecureCredentialsStore().putCredentials(location, credentials);
						} catch (SecureCredentialsStoreException e) {
						}
					}
					aRef.set(credentials);
				}
			}
		});
		return aRef.get();
	}

}
