/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.ui.decorator;

import java.util.HashMap;
import java.util.Map;

import org.vcs.bazaar.client.BazaarStatusKind;
import org.vcs.bazaar.eclipse.core.model.BzrStatus;

/**
 * Set of text labels that are used for decorating resources are maintained here.
 * This acts as a label registry.
 *
 */
public class DecoratorTextLabels extends DecoratorResources {

	public static final String addedPrefix = "+ ";
	public static final String deletedStillTrackedPrefix = "- ";
	public static final String ignoredPrefix = "I ";
	public static final String modifiedPrefix = "> ";
	public static final String notTrackedPrefix = "? ";
	public static final String removedPrefix = "- ";
	public static final String managedPrefix = "";
	public static final String conflictPrefix = "C ";
	public static final String renamePrefix = "R ";
	private static final Map<BazaarStatusKind, String> labelMap;

	static {
		labelMap = new HashMap<BazaarStatusKind, String>(9);
		labelMap.put(BazaarStatusKind.CREATED, addedPrefix);
		labelMap.put(BazaarStatusKind.MODIFIED, modifiedPrefix);
		labelMap.put(BazaarStatusKind.UNKNOWN, notTrackedPrefix);
		labelMap.put(BazaarStatusKind.DELETED, removedPrefix);
		labelMap.put(BazaarStatusKind.UNCHANGED, managedPrefix);
		labelMap.put(BazaarStatusKind.HAS_CONFLICTS, conflictPrefix);
		labelMap.put(BazaarStatusKind.RENAMED, renamePrefix);

	}

	/**
	 * Get the label depending on the key
	 *
	 * @return String
	 */
	public static final String getStatusTextLabel(BzrStatus status) {
		BazaarStatusKind kind = getStatusFlagKind(status);
		if(kind != null) {
			String value = labelMap.get(kind);
			return value==null?String.valueOf(kind.toChar())+" ":value;
		}
		return "";
	}

}
