/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.dialogs;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.layout.GridDataFactory;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.vcs.bazaar.eclipse.core.credentials.BazaarCredentials;
import org.vcs.bazaar.eclipse.core.credentials.SecureCredentialsStore;
import org.vcs.bazaar.eclipse.ui.UITexts;

/**
 * @author Piotr Piastucki based on egit's LoginDialog
 */
public class LoginDialog extends Dialog {

	private Text user;
	private Text password;
	private Button storeCheckbox;
	private BazaarCredentials credentials;
	private boolean storeInSecureStore;
	private final String location;
	private boolean isUserSet;
	private boolean passwordOnly;
	private String oldUser;

	public LoginDialog(Shell shell, String location, boolean passwordOnly) {
		super(shell);
		this.location = location;
		this.passwordOnly = passwordOnly;
		oldUser = SecureCredentialsStore.getUserFromLocation(location);
		isUserSet = oldUser != null && !oldUser.isEmpty();
	}

	@Override
	protected Control createDialogArea(Composite parent) {
		final Composite composite = (Composite) super.createDialogArea(parent);
		composite.setLayout(new GridLayout(2, false));
		getShell().setText(UITexts.LoginDialog_login);

		Label locationLabel = new Label(composite, SWT.NONE);
		locationLabel.setText(UITexts.LoginDialog_location);
		Text uriText = new Text(composite, SWT.READ_ONLY);
		uriText.setText(location);

		if (!passwordOnly || isUserSet) {
			Label userLabel = new Label(composite, SWT.NONE);
			userLabel.setText(UITexts.LoginDialog_user);
			if (isUserSet) {
				user = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
			} else {
				user = new Text(composite, SWT.BORDER);
			}
			if (oldUser != null) {
				user.setText(oldUser);
			}
			GridDataFactory.fillDefaults().grab(true, false).applyTo(user);
		}

		Label passwordLabel = new Label(composite, SWT.NONE);
		passwordLabel.setText(UITexts.LoginDialog_password);
		password = new Text(composite, SWT.PASSWORD | SWT.BORDER);
		GridDataFactory.fillDefaults().grab(true, false).applyTo(password);

		Label storeLabel = new Label(composite, SWT.NONE);
		storeLabel.setText(UITexts.LoginDialog_storeInSecureStore);
		storeCheckbox = new Button(composite, SWT.CHECK);
		storeCheckbox.setSelection(true);

		if (isUserSet || passwordOnly) {
			password.setFocus();
		} else {
			user.setFocus();
		}
		return composite;
	}

	public BazaarCredentials getCredentials() {
		return credentials;
	}

	public boolean getStoreInSecureStore() {
		return storeInSecureStore;
	}

	@Override
	protected void okPressed() {
		credentials = new BazaarCredentials(user != null ? user.getText() : null, password.getText(), false);
		storeInSecureStore = storeCheckbox.getSelection();
		super.okPressed();
	}

}
