/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.dialogs;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Shell;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.commandline.syntax.IMergeOptions;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.ui.UITexts;

/**
 *
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail.com>
 * @BasedOn RevertDialog from MercurialEclipse
 */
public class MergeDialog extends LocationInputDialog {

	private static final String TITLE = UITexts.MergeDialog_Title;
	private static final String MESSAGE = UITexts.MergeDialog_Message;
	private ArrayList<Option> options;
	private Button reprocess;
	private Button pull;
	private Button uncommitted;
	private MergeDialogInfo dialogInfo;

	/**
	 * Create the dialog
	 *
	 * @param parentShell
	 * @param selectedResources
	 * @param commiteableResources
	 */
	public MergeDialog(Shell parentShell, Collection<IBzrBranch> locations, IBzrBranch initialBranch, MergeDialogInfo dialogInfo) {
		super(parentShell, TITLE, MESSAGE, initialBranch, new BaseURIValidator(), locations, dialogInfo, true, false, true, false, false);
		setShellStyle(SWT.RESIZE | SWT.MODELESS | SWT.CLOSE | SWT.BORDER | SWT.TITLE);
		setBlockOnOpen(true);
		this.dialogInfo = dialogInfo;
	}

	@Override
    protected void createOptionsArea(Composite composite) {
		Composite container = new Composite(composite, SWT.NONE);
		container.setLayout(new GridLayout(2, false));
		container.setLayoutData(new GridData(GridData.BEGINNING, GridData.BEGINNING, true, false));

		Group checkBoxGroup = new Group(container, SWT.NONE);
		checkBoxGroup.setLayout(new GridLayout(2, true));
		super.createOptions(checkBoxGroup);
		reprocess = new Button(checkBoxGroup, SWT.CHECK);
		reprocess.setText(UITexts.MergeDialog_Reprocess);
		reprocess.setSelection(false); // Start unselected.
		reprocess.setToolTipText(UITexts.MergeDialog_ReprocessTooltip);
		pull = new Button(checkBoxGroup, SWT.CHECK);
		pull.setText(UITexts.MergeDialog_Pull);
		pull.setSelection(false); // Start unselected.
		uncommitted = new Button(checkBoxGroup, SWT.CHECK);
		uncommitted.setText(UITexts.MergeDialog_Uncommitted);
		uncommitted.setSelection(false); // Start unselected.
		uncommitted.setToolTipText(UITexts.MergeDialog_UncommittedTooltip);

		Group revisionGroup = new Group(container, SWT.NONE);
		revisionGroup.setLayout(new GridLayout());
		createRevisionSelector(revisionGroup, true);

		revisionGroup.setLayoutData(new GridData(GridData.FILL, GridData.FILL, true, false));
		checkBoxGroup.setLayoutData(new GridData(GridData.FILL, GridData.FILL, true, false));
		container.setLayoutData(new GridData(GridData.FILL_BOTH));
	}

	@Override
	protected void okPressed() {
		this.options = new ArrayList<Option>(0);
		if(isRemember()) {
			options.add(IMergeOptions.REMEMBER);
		}
		if(isForce()) {
			options.add(IMergeOptions.FORCE);
		}
		if(pull.getSelection()) {
			options.add(IMergeOptions.PULL);
		}
		if(reprocess.getSelection()) {
			options.add(IMergeOptions.REPROCESS);
		}
		if(uncommitted.getSelection()) {
			options.add(IMergeOptions.UNCOMMITTED);
		}
		if(isRevisionSelected()) {
			options.add(IMergeOptions.REVISION.setArgument(getSelectedRevision()));
		}
		this.dialogInfo.options = options;
		super.okPressed();
	}

	public static class MergeDialogInfo extends LocationDialogInfo {
		List<Option> options;

		public List<Option> getOptions() {
			return options;
		}
	}

	// this main is for test the dialog during development
    @SuppressWarnings("unchecked")
    public static void main(String[] args) {
		Display display = new Display();
		Shell shell = new Shell(display);
		shell.setMinimumSize(280, 430);
		MergeDialog dialog = new MergeDialog(shell, Collections.EMPTY_LIST, null, new MergeDialogInfo());
		dialog.setBlockOnOpen(true);
		int exit = dialog.open();
		System.out.println("exit: " + exit);
	}
}
