/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.dialogs;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.commandline.syntax.IMergeOptions;
import org.vcs.bazaar.client.commandline.syntax.ITagOptions;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.widgets.RevisionNumber;

/**
 * @author Piotr Piastucki
 */
public class TagDialog extends Dialog {

	IBzrBranch branch;
	private Text tagText;
	private Button force;
	private RevisionNumber revision;
	private String tagName;
	private List<Option> options;
	
	public TagDialog(Shell parentShell, IBzrBranch branch) {
		super(parentShell);
		this.branch = branch;
		setShellStyle(SWT.RESIZE | SWT.MODELESS | SWT.CLOSE | SWT.BORDER | SWT.TITLE);
		setBlockOnOpen(true);
	}

	@Override
	protected Point getInitialSize() {
		return new Point(450, 300);
	}

	@Override
	protected Control createDialogArea(Composite parent) {
		Composite container = (Composite) super.createDialogArea(parent);
		getShell().setText(UITexts.TagDialog_title);
		container.setLayout(new GridLayout(1, false));
		container.setLayoutData(new GridData(GridData.FILL_BOTH));
		final Label tagLabel = new Label(container, SWT.HORIZONTAL);
		tagLabel.setText(UITexts.TagDialog_tagLabel);
		tagText = new Text(container, SWT.SINGLE | SWT.WRAP | SWT.BORDER);
		tagText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		Group optionGroup = new Group(container, SWT.NONE);
		GridData data;
		data = new GridData();
		data.horizontalAlignment = GridData.FILL;
		data.verticalAlignment = GridData.BEGINNING;
		data.grabExcessHorizontalSpace = true;
		data.grabExcessVerticalSpace = true;
		optionGroup.setLayoutData(data);
		optionGroup.setText(UITexts.Dialog_optionsGroup);
		optionGroup.setLayout(new GridLayout(1, false));
		force = new Button(optionGroup, SWT.CHECK);
		force.setText(UITexts.Dialog_optionForce);
		force.setToolTipText(UITexts.TagDialog_forceTooltip);
		force.setSelection(false);
		revision = new RevisionNumber(optionGroup);
		revision.addShowLogButtonSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				showLog();
			}
		});
		return container;
	}

	protected void showLog() {
		if (branch != null) {
			ShowLogDialog dialog = new ShowLogDialog(getShell(), branch);
			if (dialog.open() == Dialog.OK && dialog.getSelectedRevision() != null) {
				revision.setRevision(dialog.getSelectedRevision().getValue());
			}
		}
	}

	@Override
	protected void okPressed() {
		tagName = tagText.getText();
		options = new ArrayList<Option>();
		if (force.getSelection()) {
			options.add(ITagOptions.FORCE);
		}
		if(revision.isRevisionSelected()) {
			options.add(IMergeOptions.REVISION.setArgument(revision.getRevision()));
		}
		super.okPressed();
	}

	public String getTagName() {
		return tagName;
	}

	public Option[] getOptions() {
		return options.toArray(new Option[0]);
	}

	public static void main(String[] args) {
		Display display = new Display();
		Shell shell = new Shell(display);
		shell.setMinimumSize(280, 400);
		TagDialog dialog = new TagDialog(shell, null);
		dialog.setBlockOnOpen(true);
		int exit = dialog.open();
		System.out.println("exit: " + exit + " " + dialog.getTagName() + " " + dialog.getOptions());
	}

}
