/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.dialogs;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.layout.GridDataFactory;
import org.eclipse.jface.layout.GridLayoutFactory;
import org.eclipse.jface.layout.TableColumnLayout;
import org.eclipse.jface.viewers.ArrayContentProvider;
import org.eclipse.jface.viewers.ColumnWeightData;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableColumn;
import org.vcs.bazaar.client.BazaarShelf;
import org.vcs.bazaar.client.IBazaarShelf;
import org.vcs.bazaar.eclipse.ui.UITexts;

/**
 * @author Piotr Piastucki
 */
public class UnShelveDialog extends Dialog {

	private List<IBazaarShelf> shelves;
	private TableViewer tableViewer;
	private Button dryRunButton;
	private Button keepButton;
	private Button deleteOnlyButton;
	private String shelfId;
	private boolean dryRun;
	private boolean keep;
	private boolean deleteOnly;

	public UnShelveDialog(Shell parentShell) {
		super(parentShell);
		setShellStyle(SWT.RESIZE | SWT.MODELESS | SWT.CLOSE | SWT.BORDER | SWT.TITLE);
		setBlockOnOpen(true);
	}

	@Override
	protected Control createDialogArea(Composite parent) {
		getShell().setText(UITexts.UnShelveDialog_title);
		Composite container = (Composite) super.createDialogArea(parent);
		GridLayoutFactory.swtDefaults().applyTo(container);
		GridDataFactory.fillDefaults().grab(true, true).applyTo(container);

		int tableStyle = SWT.H_SCROLL | SWT.V_SCROLL | SWT.FULL_SELECTION | SWT.MULTI | SWT.BORDER;

		Composite tablecontainer = new Composite(container, SWT.NONE);

		final Table table = new Table(tablecontainer, tableStyle);
		table.setHeaderVisible(true);
		table.setLinesVisible(true);

		TableColumnLayout layout = new TableColumnLayout();
		tablecontainer.setLayout(layout);
		// File name
		final TableColumn file = new TableColumn(table, SWT.LEFT);
		file.setResizable(true);
		file.setText(UITexts.UnShelveDialog_shelfId);
		layout.setColumnData(file, new ColumnWeightData(10, true));

		final TableColumn pattern = new TableColumn(table, SWT.LEFT);
		pattern.setResizable(true);
		pattern.setText(UITexts.UnShelveDialog_message);
		layout.setColumnData(pattern, new ColumnWeightData(90, true));

		tableViewer = new TableViewer(table);
		tableViewer.setContentProvider(new ArrayContentProvider());
		tableViewer.setLabelProvider(new ShelfListLabelProvider());
		tableViewer.setInput(shelves.toArray(new IBazaarShelf[0]));
		if (!shelves.isEmpty()) {
			tableViewer.setSelection(new StructuredSelection(shelves.subList(0, 1)));
		}
		GridDataFactory gf = GridDataFactory.fillDefaults().align(GridData.FILL, GridData.FILL).grab(true, true);
		gf.applyTo(tablecontainer);

		Group optionGroup = new Group(container, SWT.NONE);
		optionGroup.setText(UITexts.Dialog_optionsGroup);
		optionGroup.setLayout(new GridLayout(2, true));
		GridDataFactory.fillDefaults().align(GridData.FILL, GridData.BEGINNING).grab(true, false).applyTo(optionGroup);
		Composite composite = new Composite(optionGroup, SWT.NONE);
		composite.setLayout(new GridLayout());
		GridDataFactory.fillDefaults().align(GridData.FILL, GridData.BEGINNING).grab(true, false).applyTo(composite);
		dryRunButton = new Button(composite, SWT.CHECK);
		dryRunButton.setText(UITexts.UnShelveDialog_dryRun);
		dryRunButton.setToolTipText(UITexts.UnShelveDialog_dryRunTooltip);
		dryRunButton.setSelection(false);

		keepButton = new Button(composite, SWT.CHECK);
		keepButton.setText(UITexts.UnShelveDialog_keep);
		keepButton.setToolTipText(UITexts.UnShelveDialog_keepTooltip);
		keepButton.setSelection(false);

		composite = new Composite(optionGroup, SWT.NONE);
		composite.setLayout(new GridLayout());
		GridDataFactory.fillDefaults().align(GridData.FILL, GridData.BEGINNING).grab(true, false).applyTo(composite);

		deleteOnlyButton = new Button(composite, SWT.CHECK);
		deleteOnlyButton.setText(UITexts.UnShelveDialog_deleteOnly);
		deleteOnlyButton.setToolTipText(UITexts.UnShelveDialog_deleteOnlyTooltip);
		deleteOnlyButton.setSelection(false);

		return container;
	}
	
	private static class ShelfListLabelProvider extends LabelProvider implements ITableLabelProvider {

		public Image getColumnImage(Object element, int columnIndex) {
			return null;
		}

		public String getColumnText(Object element, int columnIndex) {
			if (element instanceof IBazaarShelf) {
		        switch (columnIndex) {
		        case 0:
		            return ((IBazaarShelf)element).getId();
		        case 1:
		            return ((IBazaarShelf)element).getMessage();
		        }
			}
            return "N/A";
		}
		
	}

	@Override
	protected void okPressed() {
		IStructuredSelection sel = (IStructuredSelection) tableViewer.getSelection();
		if (!sel.isEmpty()) {
			shelfId = ((IBazaarShelf)sel.getFirstElement()).getId();
		} else {
			shelfId = null;
		}
		dryRun = dryRunButton.getSelection();
		keep = keepButton.getSelection();
		deleteOnly = deleteOnlyButton.getSelection();
		super.okPressed();
	}

	public String getShelfId() {
		return shelfId;
	}

	public boolean isDryRun() {
		return dryRun;
	}

	public boolean isKeep() {
		return keep;
	}

	public boolean isDeleteOnly() {
		return deleteOnly;
	}

	@Override
	protected Point getInitialSize() {
		return new Point(500, 400);
	}

	public int open(List<IBazaarShelf> shelves) {
		this.shelves = shelves;
		return super.open();
	}

	public static void main(String[] args) {
		Display display = new Display();
		Shell shell = new Shell(display);
		shell.setMinimumSize(280, 400);
		BazaarShelf shelf1 = new BazaarShelf("1", "shelf 1");
		BazaarShelf shelf2 = new BazaarShelf("2", "shelf 2");
		List<IBazaarShelf> shelves = new ArrayList<IBazaarShelf>();
		shelves.add(shelf1);
		shelves.add(shelf2);
		UnShelveDialog dialog = new UnShelveDialog(shell);
		int exit = dialog.open(shelves);
		System.out.println("exit: " + exit);
	}

}
