/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.history;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.team.core.history.IFileRevision;
import org.eclipse.team.core.history.provider.FileRevision;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.IBazaarStatus;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.resources.IStorageBazaarRevision;
import org.vcs.bazaar.eclipse.core.utils.ResourceUtil;

/**
 * @author Piotr Piastucki
 */
public class AffectedPathsItem extends FileRevision {

	private final IBzrBranch branch;
	private final IBazaarStatus status;
	private final BazaarRevision revision;
	private final IResource resource;
	IStorageBazaarRevision storageBazaarRevision;
	private final boolean selected;

	public AffectedPathsItem(IBzrBranch branch, IBazaarStatus status, BazaarRevision revision, boolean selected) {
		this.branch = branch;
		this.status = status;
		this.revision = revision;
		this.selected = selected;
		IPath path = branch.getPath().append(status.getPath());
		resource = ResourceUtil.getIResource(path, status.isDirectory());
	}

	public IBazaarStatus getStatus() {
		return status;
	}

	public BazaarRevision getRevision() {
		return revision;
	}

	public IStorageBazaarRevision getStorage(IProgressMonitor monitor) throws CoreException {
		if (storageBazaarRevision == null) {
			storageBazaarRevision = new IStorageBazaarRevision(resource, branch, status.getPath(), revision);
		}
		return storageBazaarRevision;
	}

	public String getName() {
		return status.getPath();
	}

	public boolean isPropertyMissing() {
		return false;
	}

	public IFileRevision withAllProperties(IProgressMonitor monitor) throws CoreException {
		return null;
	}

	@Override
	public String getContentIdentifier() {
		return revision.toString();
	}

	public boolean isSelected() {
		return selected;
	}

	public IResource getResource() {
		return resource;
	}
	
}
