/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.history;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.resource.JFaceResources;
import org.eclipse.jface.resource.LocalResourceManager;
import org.eclipse.jface.resource.ResourceManager;
import org.eclipse.jface.viewers.DecorationOverlayIcon;
import org.eclipse.jface.viewers.IDecoration;
import org.eclipse.jface.viewers.ITableColorProvider;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Display;
import org.vcs.bazaar.client.BazaarStatusKind;
import org.vcs.bazaar.client.IBazaarStatus;
import org.vcs.bazaar.eclipse.ui.UIUtils;
import org.vcs.bazaar.eclipse.ui.decorator.DecoratorImages;

/**
 * @author Piotr Piastucki
 */
public class AffectedPathsLabelProvider extends LabelProvider implements ITableLabelProvider, ITableColorProvider {

	private ResourceManager resourceManager = new LocalResourceManager(JFaceResources.getResources());
	
	public Image getImage(IBazaarStatus status) {
		ImageDescriptor id = UIUtils.getEditorImage(status);
		Image base = (Image) resourceManager.get(id);
		if (status.contains(BazaarStatusKind.CREATED) 
			|| status.contains(BazaarStatusKind.DELETED)
			|| status.contains(BazaarStatusKind.RENAMED)) {
			ImageDescriptor im =  new DecorationOverlayIcon(base, DecoratorImages.getImageDescriptor(status), IDecoration.BOTTOM_RIGHT);
			base = (Image) resourceManager.get(im);
		}
		return base;
	}
	
	public Image getColumnImage(Object element, int columnIndex) {
		if (!(element instanceof AffectedPathsItem)) {
			return null;
		}
		IBazaarStatus status = ((AffectedPathsItem) element).getStatus();
		return getImage(status);
	}

	public String getColumnText(Object element, int columnIndex) {
		if (!(element instanceof AffectedPathsItem)) {
			return "Type Error"; //$NON-NLS-1$
		}
		IBazaarStatus status = ((AffectedPathsItem) element).getStatus();
		return status.getPath();
	}

	@Override
	public void dispose() {
		resourceManager.dispose();
		super.dispose();
	}

	public Color getForeground(Object element, int columnIndex) {
		if (!(element instanceof AffectedPathsItem)) {
			return null;
		}
		if (!((AffectedPathsItem)element).isSelected()) {
			return Display.getDefault().getSystemColor(SWT.COLOR_GRAY);
		}
		return null;
	}

	public Color getBackground(Object element, int columnIndex) {
		return null;
	}
	
}
