/*******************************************************************************
 * Copyright (c) 2007-2013 Guillermo Gonzalez
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.history;

import org.eclipse.core.resources.IResource;
import org.eclipse.team.core.RepositoryProvider;
import org.eclipse.team.ui.history.HistoryPageSource;
import org.eclipse.ui.part.Page;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;

/**
 * 
 * @author Guillermo Gonzalez
 * 
 */
public class BazaarHistoryPageSource extends HistoryPageSource {

	public BazaarHistoryPageSource() {
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.team.ui.history.IHistoryPageSource#canShowHistoryFor(java
	 * .lang.Object)
	 */
	public boolean canShowHistoryFor(Object object) {
		if (object instanceof IResource && ((IResource) object).getType() != IResource.ROOT) {
			IResource resource = (IResource) object;
			RepositoryProvider provider = RepositoryProvider.getProvider(resource.getProject());
			if (provider instanceof BazaarTeamProvider) {
				return true;
			}
		} else if (object instanceof BazaarHistoryPageInput) {
			return true;
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.team.ui.history.IHistoryPageSource#createPage(java.lang.Object
	 * )
	 */
	public Page createPage(Object object) {
		if (object instanceof IResource) {
			return new BazaarHistoryPage(new BazaarHistoryPageInput(BzrWorkspaceRoot.getBzrResourceFor((IResource) object), new IResource[] {(IResource) object}));
		} else if (object instanceof BazaarHistoryPageInput) {
			return new BazaarHistoryPage((BazaarHistoryPageInput) object);
		}
		return null;
	}

}
