/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.notifications;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.PlatformUI;
import org.vcs.bazaar.eclipse.core.notifications.Notification;
import org.vcs.bazaar.eclipse.core.notifications.NotificationListener;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.actions.ReconfigureLightweightCheckoutsAction;
import org.vcs.bazaar.eclipse.ui.operations.ReconfigureLightweightCheckoutsOperation;
import org.vcs.bazaar.eclipse.ui.preferences.BazaarPreferenceConstants;

/**
 * @author Piotr Piastucki
 */
public class BazaarNotificationListener implements NotificationListener {

	private static final long HOURS_BETWEEN_NOTIFICATION = 8;
	public void message(final Notification message) {
		IPreferenceStore ps = EclipseBazaarUI.getDefault().getPreferenceStore();
		long ts = ps.getLong(BazaarPreferenceConstants.NOTIFICATION_TIMESTAMP_PREFIX + message.getCategory());
		if (ts + HOURS_BETWEEN_NOTIFICATION * 3600000 > System.currentTimeMillis()) {
			return;
		}
		ps.setValue(BazaarPreferenceConstants.NOTIFICATION_TIMESTAMP_PREFIX + message.getCategory(), System.currentTimeMillis());
		EclipseBazaarUI.getStandardDisplay().asyncExec(new Runnable() {
			public void run() {
				if (ReconfigureLightweightCheckoutsOperation.RUNNING.getAndSet(true)) {
					return;
				}
				Shell lShell = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell();
				switch (message.getCategory()) {
				case LIGHTWEIGHT_CHECKOUTS:
					boolean convert = MessageDialog.openQuestion(lShell, 
							UITexts.Notification_lightweightCheckoutsTitle, 
							UITexts.Notification_lightweightCheckoutsQuestion);
					/*
					MessageDialog.openWarning(lShell,
							UITexts.Notification_lightweightCheckoutsTitle,
							UITexts.Notification_lightweightCheckoutsText);
							*/
					if (convert) {
						new ReconfigureLightweightCheckoutsAction().run(null);
					}
					break;
				}
			}
		});
	}

}
