/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.operations;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.team.core.RepositoryProvider;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.AddCommand;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;

/**
 * @author Piotr Piastucki
 */
public class AddOperation {

	private final IResource[] selectedResources;
	private final boolean nestedInAnotherOperation;

	public AddOperation(IResource[] selectedResources, boolean nestedInAnotherOperation) {
		this.selectedResources = selectedResources;
		this.nestedInAnotherOperation = nestedInAnotherOperation;
	}

	public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
		try {
			Map<BazaarTeamProvider, List<IResource>> map = getProviderMapping(selectedResources);
			Set<BazaarTeamProvider> keySet = map.keySet();
			monitor.beginTask("", keySet.size() * 1000); //$NON-NLS-1$
			monitor.setTaskName(CoreTexts.AddCommand_adding); //$NON-NLS-1$
			for (BazaarTeamProvider provider : keySet) {
				List<IResource> resources = map.get(provider);
				AddCommand op = new AddCommand(provider.getBzrWorkspaceRoot(), resources);
				if (nestedInAnotherOperation) {
					op.execute(monitor);
					monitor.worked(1000);
				} else {
					op.run(EclipseBazaarCore.subProgressMonitorFor(monitor));
				}
			}
		} catch (CoreException e) {
			EclipseBazaarUI.log(e.getMessage(), e);
			throw new InvocationTargetException(e);
		} finally {
			monitor.done();
		}
	}

	/**
	 * Return a map for the resources and it's (project) provider
	 */
	protected Hashtable<BazaarTeamProvider, List<IResource>> getProviderMapping(IResource[] resources) {
		Hashtable<BazaarTeamProvider, List<IResource>> result = new Hashtable<BazaarTeamProvider, List<IResource>>();
		for (IResource resource : resources) {
			BazaarTeamProvider provider = (BazaarTeamProvider) RepositoryProvider
					.getProvider(resource.getProject(), EclipseBazaarCore.getProviderID());
			// TODO: check for null provider?
			List<IResource> list = result.get(provider);
			if (list == null) {
				list = new ArrayList<IResource>();
				result.put(provider, list);
			}
			list.add(resource);
		}
		return result;
	}
	
}
