/*******************************************************************************
 * Copyright (c) 2012 Idereal Limited
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Alexander Taler
 *    Piotr Piastucki
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.operations;

import java.io.File;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.operation.IRunnableContext;
import org.eclipse.team.ui.TeamOperation;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.commandline.syntax.ICheckoutOptions;
import org.vcs.bazaar.eclipse.core.commands.BranchCommand;
import org.vcs.bazaar.eclipse.core.commands.CheckoutCommand;
import org.vcs.bazaar.eclipse.core.commands.IBazaarCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.ui.branch.BranchLocationManager;

/**
 * Operation for creating project(s) from a Bazaar branch.
 * 
 * Influenced by earlier implementation by Guillermo Gonzalez.
 * 
 * @author Alexander Taler alex <@> idereal <.> co <.> nz
 * @author Piotr Piastucki
 */
public class CheckoutBazaarProjectOperation extends TeamOperation {

	public static int TYPE_CHECKOUT = 1;
	public static int TYPE_LIGHTWEIGHT = 2;
	public static int TYPE_BRANCH = 3;

	IBzrBranch remoteBranch;
	File projectLocation;
	int type;
	String revision;

	/**
	 * 
	 * @param context
	 *            Found with getContainer()
	 * @param remoteBranch
	 *            The branch to get code from
	 * @param projectLocation
	 *            Where on disk to check out the project
	 * @param type
	 *            The type of operation, one of TYPE_CHECKOUT, TYPE_LIGHTWEIGHT,
	 *            TYPE_BRANCH
	 * @param revision
	 *            Optional revision, null means use tip
	 */
	public CheckoutBazaarProjectOperation(IRunnableContext context, IBzrBranch remoteBranch,
			String projectLocation, int type, String revision) {
		super(context);
		this.remoteBranch = remoteBranch;
		this.projectLocation = new File(projectLocation);
		this.type = type;
		this.revision = revision;
	}

	public void run(IProgressMonitor monitor) throws InvocationTargetException {
		try {
			IBazaarCommand op;
			if (type == TYPE_BRANCH) {
				op = new BranchCommand(remoteBranch, projectLocation, revision);
			} else {
				List<Option> options = new ArrayList<Option>(0);
				if (type == TYPE_LIGHTWEIGHT) {
					options.add(ICheckoutOptions.LIGHTWEIGHT);
				}
				if ((revision != null) && revision.trim().length() > 0) {
					String s = BazaarRevision.getRevision(BazaarRevision.Prefix.REVNO, revision).toString();
					options.add(ICheckoutOptions.REVISION.setArgument(s));
				}
				op = new CheckoutCommand(remoteBranch, projectLocation, options.toArray(new Option[0]));
			}
			op.run(monitor);
			BranchLocationManager.saveBranchLocation(remoteBranch.getBranchLocation().toString());
		} catch (Exception e) {
			throw new InvocationTargetException(e);
		}
	}

}
