/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.operations;

import java.lang.reflect.InvocationTargetException;
import java.util.List;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.operation.IRunnableContext;
import org.vcs.bazaar.client.IBazaarRevisionSpec;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.CreatePatchCommand;
import org.vcs.bazaar.eclipse.core.commands.RemoveCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.actions.WorkbenchAction;

/**
 * @author Piotr Piastucki
 */
public class CreatePatchOperation extends BzrOperation {

	private final List<IBzrResourceStatus> resources;
	private final IBazaarRevisionSpec revision;
	private final Option[] options;
	private String patchContent;

	public CreatePatchOperation(IRunnableContext context, List<IBzrResourceStatus> list, IBazaarRevisionSpec revision, Option[] options) {
		super(context);
		this.resources = list;
		this.revision = revision;
		this.options = options;
	}
	
	public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
		final List<IResource> filesToAdd = WorkbenchAction.getUnknownResources(resources); 
		if (!filesToAdd.isEmpty()) {
			new AddOperation(filesToAdd.toArray(new IResource[0]), true).run(EclipseBazaarCore.subProgressMonitorFor(monitor));
		}
		try {
			CreatePatchCommand cmd = new CreatePatchCommand(WorkbenchAction.getResources(resources), revision, options);
			cmd.run(EclipseBazaarCore.subProgressMonitorFor(monitor));
			patchContent = cmd.getPatchContent();
		} catch (BazaarException e) {
			throw new InvocationTargetException(e);
		} finally {
			RemoveCommand rcmd = new RemoveCommand(BzrWorkspaceRoot.getBzrResourcesFor(filesToAdd.toArray(new IResource[0])));
			try {
				rcmd.run(EclipseBazaarCore.subProgressMonitorFor(monitor));
			} catch (BazaarException e) {
				throw new InvocationTargetException(e);
			}
		}
	}

	public String getPatchContent() {
		return patchContent;
	}

}
