/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.operations;

import java.lang.reflect.InvocationTargetException;
import java.util.HashSet;
import java.util.Set;
import java.util.concurrent.atomic.AtomicBoolean;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.operation.IRunnableContext;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.ReconfigureCommand;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalBranch;
import org.vcs.bazaar.eclipse.core.repository.BranchFactory;
import org.vcs.bazaar.eclipse.internal.core.model.ProjectBranch;

/**
 * @author Piotr Piastucki
 */
public class ReconfigureLightweightCheckoutsOperation extends BzrOperation{

	public static final AtomicBoolean RUNNING = new AtomicBoolean();
	
	public ReconfigureLightweightCheckoutsOperation(IRunnableContext context) {
		super(context);
	}

	public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
    	Exception e = null;
        try {
        	Set<ProjectBranch> branches = new HashSet<ProjectBranch>();
            Set<IProject> lcProjects = new HashSet<IProject>();
            IProject[] projects = ResourcesPlugin.getWorkspace().getRoot().getProjects();
            for (IProject project : projects) {
            	if (BzrWorkspaceRoot.isLightweightCheckout(project)) {
            		lcProjects.add(project);
            		branches.add(BranchFactory.findOrCreateFor(project));
            	}
            }
            if (!branches.isEmpty()) {
				monitor.beginTask("", 1000 * branches.size()); //$NON-NLS-1$
				for (ProjectBranch branch : branches) {
					ReconfigureCommand cmd = new ReconfigureCommand(branch);
					try {
						cmd.run(EclipseBazaarCore.subProgressMonitorFor(monitor));
					} catch (Exception e1) {
						e = e1;
					}
				}
				for (IProject project : lcProjects) {
					IBzrLocalBranch branch = BzrWorkspaceRoot.getBranchFor(project);
					if (branch instanceof ProjectBranch) {
						((ProjectBranch)branch).setDirty(true);
					}
				}
            }
        } catch (Exception e1) {
        	e = e1;
		} finally {
			RUNNING.set(false);
			monitor.done();
		}
        if (e != null) {
			throw new InvocationTargetException(e, e.getMessage());
        }
	}
}
