/*******************************************************************************
* Copyright (c) 2007-2013 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.ui.operations;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.ui.IWorkbenchPart;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.commands.SendCommand;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.internal.core.model.ProjectBranch;

/**
 * @author Javier Der Derian <javierder at gmail dot com>
 * @BasedOn PushOperation from BzrEclipse
 */
public class SendOperation extends BzrOperation {

	private final IBzrLocalResource resource;
	private Option[] options;
	private BranchLocation branchLocation;

	public SendOperation(IWorkbenchPart part, IBzrLocalResource bzrResource, Option[] options, BranchLocation branchLocation) {
		super(part);
		this.resource = bzrResource;
		this.options = options;
		this.branchLocation = branchLocation;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.operation.IRunnableWithProgress#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
		try {
			monitor.beginTask(CoreTexts.bind(CoreTexts.SendCommand_send, branchLocation.toString()), 1000);
			final SendCommand cmd = new SendCommand(resource, options, branchLocation);
			cmd.run(monitor);
			if (resource.getBranch() instanceof ProjectBranch) {
				((ProjectBranch)resource.getBranch()).setDirty(true);
			}
		} catch (BazaarException e) {
			throw new InvocationTargetException(e);
		} finally {
			monitor.done();
		}
	}

	@Override
	protected String getJobName() {
		return "Sending " + resource.getName();
	}

	@Override
	protected boolean canRunAsJob() {
		return true;
	}

}
