/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.repository;

import java.util.Set;
import java.util.TreeSet;

import org.eclipse.core.resources.IProject;
import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.IOpenListener;
import org.eclipse.jface.viewers.OpenEvent;
import org.eclipse.jface.viewers.TreeSelection;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.ISelectionService;
import org.eclipse.ui.contexts.IContextService;
import org.eclipse.ui.navigator.CommonNavigator;
import org.eclipse.ui.navigator.CommonViewer;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.utils.ResourceUtil;
import org.vcs.bazaar.eclipse.ui.branch.BranchLocationManager;
import org.vcs.bazaar.eclipse.ui.repository.tree.RepositoryRootNode;
import org.vcs.bazaar.eclipse.ui.repository.tree.RepositoryTreeNode;

/**
 * @author Piotr Piastucki
 */
public class RepositoriesView extends CommonNavigator {

	public static final String VIEW_ID = "org.vcs.bazaar.eclipse.ui.repository.RepositoriesView"; //$NON-NLS-1$
	
	private final Set<IBzrBranch> branches = new TreeSet<IBzrBranch>();
	
	@Override
	protected CommonViewer createCommonViewer(Composite parent) {
		CommonViewer viewer = super.createCommonViewer(parent);
		// handle the double-click event for tags and branches
		viewer.addDoubleClickListener(new IDoubleClickListener() {
			public void doubleClick(DoubleClickEvent event) {
				TreeSelection sel = (TreeSelection) event.getSelection();
				/*
				RepositoryTreeNode element = (RepositoryTreeNode) sel
						.getFirstElement();
				if (element instanceof RefNode || element instanceof TagNode)
					executeOpenCommand();
					*/
			}
		});
		// handle open event for the working directory
		viewer.addOpenListener(new IOpenListener() {
			public void open(OpenEvent event) {
				TreeSelection sel = (TreeSelection) event.getSelection();
				RepositoryTreeNode element = (RepositoryTreeNode) sel
						.getFirstElement();
				/*
				if (element instanceof FileNode
						|| element instanceof StashedCommitNode)
					executeOpenCommand();
					*/
			}
		});
		// react on selection changes
		ISelectionService srv = (ISelectionService) getSite().getService(ISelectionService.class);
	//	srv.addPostSelectionListener(selectionChangedListener);
		// react on changes in the configured repositories
		/*
		repositoryUtil.getPreferences().addPreferenceChangeListener(configurationListener);
		initRepositoriesAndListeners();
		*/
/*
		emptyArea.setBackground(viewer.getControl().getBackground());
		if (!repositories.isEmpty())
			layout.topControl = viewer.getControl();
		else
			layout.topControl = emptyArea;
*/
		initBranches();
		//activateContextService();
		return viewer;
	}

	@Override
	protected Object getInitialInput() {
		return new RepositoryRootNode(branches);
		
	}
	
	private void activateContextService() {
		IContextService contextService = (IContextService) getSite()
				.getService(IContextService.class);
		if (contextService != null)
			contextService.activateContext(VIEW_ID);

	}
	
	private void initBranches() {
		synchronized (branches) {
			branches.clear();
			//unregisterRepositoryListener();
			// listen for repository changes
			IProject[] projects =  ResourceUtil.findProjects();
			for (IProject project : projects) {
				branches.add(BzrWorkspaceRoot.getBzrResourceFor(project).getBranch());
			}
			for (IBzrBranch branch : BranchLocationManager.getAllBranches()) {
				if (branch != null && branch.isLocal()) {
					if (branch.exists()) {
						branches.add(branch);
					}
				}
			}
		}
	}
	

	
}
