/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.repository.tree;

import java.util.ArrayList;
import java.util.List;

import org.vcs.bazaar.eclipse.core.model.IBzrBranch;

/**
 * @author Piotr Piastucki
 */
public class RepositoryBranchNode extends RepositoryTreeNode {

	private final IBzrBranch branch;
	private String name;
	private boolean project;
	
	public RepositoryBranchNode(IBzrBranch branch) {
		super(null, RepositoryTreeNodeType.BRANCH);
		this.branch = branch;
	}

	public IBzrBranch getBranch() {
		return branch;
	}

	@Override
	public String getName() {
		if (name == null) {
			try {
				name = branch.getNick();
			} catch (Exception e) {
				name = "Error!";
			}
		}
		return name;
	}
	
	@Override
	public String getLocation() {
		return branch.getBranchLocation().toString();
	}

	public boolean isProject() {
		return project;
	}
	
	@Override
	public boolean hasChildren() {
		return true;
	}
	
	@Override
	public List<RepositoryTreeNode> getChildren() {
		List<RepositoryTreeNode> nodes = new ArrayList<RepositoryTreeNode>();
		nodes.add(new RepositoryRemotesNode(this));
		nodes.add(new RepositoryTagsNode(this));
		return nodes;
	}
	
}
