/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.repository.tree;

import java.util.ArrayList;
import java.util.List;

import org.vcs.bazaar.client.IBazaarInfo;
import org.vcs.bazaar.client.IBazaarInfo.RelatedBranches;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.repository.BranchFactory;
import org.vcs.bazaar.eclipse.internal.core.model.LocalBranch;

/**
 * @author Piotr Piastucki
 */
public class RepositoryRemotesNode extends RepositoryTreeNode {

	private final IBzrBranch branch;
	
	public RepositoryRemotesNode(RepositoryBranchNode branch) {
		super(branch, RepositoryTreeNodeType.REMOTES);
		this.branch = branch.getBranch();
	}
	
	@Override
	public String getName() {
		return "Remotes"; // FIXME: Translation
	}
	
	private void addBranch(String name, String location, List<RepositoryTreeNode> nodes) {
		if (location != null) {
			IBzrBranch branch = BranchFactory.findOrCreateFor(location);
			if (branch != null && !branch.isLocal()) {
				nodes.add(new RepositoryRemoteNode(this, name, branch));
			}
		}
	}
	
	@Override
	public List<RepositoryTreeNode> getChildren() {
		List<RepositoryTreeNode> nodes = new ArrayList<RepositoryTreeNode>();
		if (branch instanceof LocalBranch) {
			IBazaarInfo info = ((LocalBranch)branch).getInfo();
			RelatedBranches branches = info.getRelatedBranches();
			if (branches != null) {
				addBranch("Parent", branches.getParentBranch(), nodes);
				addBranch("Public", branches.getPublicBranch(), nodes);
				addBranch("Push", branches.getPushBranch(), nodes);
				addBranch("Submit", branches.getSubmitBranch(), nodes);
			}
			if (info.getLocations() != null) {
				addBranch("Bound to", info.getLocations().getBoundToBranch(), nodes);
				addBranch("Checkout of", info.getLocations().getCheckoutOfBranch(), nodes);
			}
		}
		return nodes;
	}

	@Override
	public boolean hasChildren() {
		return true;
	}
}
