/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.repository.tree;

import java.util.ArrayList;
import java.util.List;

import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.IBazaarTag;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Piotr Piastucki
 */
public class RepositoryTagsNode extends RepositoryTreeNode {

	public RepositoryTagsNode(RepositoryBranchNode parent) {
		super(parent, RepositoryTreeNodeType.TAGS);
	}

	@Override
	public boolean hasChildren() {
		return true;
	}
	
	protected List<IBazaarTag> getTags() {
		IBzrBranch branch = ((RepositoryBranchNode)parent).getBranch();
		try {
			IBazaarClient client = EclipseBazaarCore.getDefault().createClient();
			client.setWorkDir(branch.getFile());
			return client.tags();
		} catch (BazaarException e) {
			throw BazaarException.makeUnChecked(e);
		} catch (BazaarClientException e) {
			throw BazaarClientException.makeUnChecked(e);
		}
	}
	
	@Override
	public List<RepositoryTreeNode> getChildren() {
		List<RepositoryTreeNode> nodes = new ArrayList<RepositoryTreeNode>();
		List<IBazaarTag> tags = getTags();
		for (IBazaarTag tag : tags) {
			RepositoryTagNode node = new RepositoryTagNode(this, tag);
			nodes.add(node);
		}
		return nodes;
	}

	@Override
	public String getName() {
		return "Tags"; // FIXME: Translation
	}
	
}
