/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.repository.tree.command;

import java.util.List;

import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.team.ui.TeamUI;
import org.eclipse.ui.progress.UIJob;
import org.vcs.bazaar.eclipse.core.utils.BzrJobStatus;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.history.BazaarHistoryPageInput;
import org.vcs.bazaar.eclipse.ui.repository.tree.RepositoryBranchNode;

/**
 * @author Piotr Piastucki
 */
public class HistoryCommand extends RepositoriesViewCommandHandler<RepositoryBranchNode> {

	public Object execute(ExecutionEvent event) throws ExecutionException {
		UIJob job = createJob(event);
		job.setUser(true);
		job.setPriority(UIJob.BUILD);
		job.schedule();
		return null;
	}

	private UIJob createJob(final ExecutionEvent event) {
		return new UIJob(getShell(event).getDisplay(), "Fetching revision history") {
			@Override
			public IStatus runInUIThread(IProgressMonitor monitor) {
				monitor.beginTask("fetching...", 100);
				List<RepositoryBranchNode> node;
				try {
					node = getSelectedNodes(event);
					monitor.subTask("fetching resource revisions");
					monitor.worked(20);
					TeamUI.getHistoryView().showHistoryFor(new BazaarHistoryPageInput(node.get(0).getBranch(), null));
					return BzrJobStatus.OK_STATUS;
				} catch (Exception e) {
					EclipseBazaarUI.log(e.getMessage(), e);
					return UIJob.errorStatus(e);
				} finally {
					monitor.done();
				}
			}
		};
	}

}
