/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.synchronize;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.compare.structuremergeviewer.IDiffElement;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.viewers.AbstractTreeViewer;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.team.ui.synchronize.ISynchronizePageConfiguration;
import org.eclipse.team.ui.synchronize.SynchronizeModelAction;
import org.eclipse.team.ui.synchronize.SynchronizeModelOperation;
import org.eclipse.team.ui.synchronize.SynchronizePageActionGroup;
import org.vcs.bazaar.eclipse.ui.UIIcons;
import org.vcs.bazaar.eclipse.ui.UITexts;

/**
 * @author Piotr Piastucki
 */
public class BazaarSynchronizeActionContributor extends SynchronizePageActionGroup {

	public static class ExpandAllModelAction extends SynchronizeModelAction {
		private static final class ExpandAllAction implements Runnable {
			private final ISynchronizePageConfiguration configuration;

			private ExpandAllAction(ISynchronizePageConfiguration configuration) {
				this.configuration = configuration;
			}

			public void run() {
				Viewer viewer = configuration.getPage().getViewer();
				if (viewer == null || viewer.getControl().isDisposed() || !(viewer instanceof AbstractTreeViewer)) {
					return;
				}
				viewer.getControl().setRedraw(false);
				((AbstractTreeViewer) viewer).expandAll();
				viewer.getControl().setRedraw(true);
			}
		}

		public ExpandAllModelAction(String text, ISynchronizePageConfiguration configuration) {
			super(text, configuration);
		}

		@Override
		protected SynchronizeModelOperation getSubscriberOperation(final ISynchronizePageConfiguration configuration,
																   IDiffElement[] elements) {
			return new SynchronizeModelOperation(configuration, elements) {
				public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
					configuration.getSite().getShell().getDisplay()
							.syncExec(new ExpandAllAction(configuration));
				}
			};
		}

		@Override
		protected boolean updateSelection(IStructuredSelection selection) {
			return true;
		}
	}

	@Override
	public void initialize(ISynchronizePageConfiguration configuration) {
		super.initialize(configuration);
		ExpandAllModelAction expandAllAction = new ExpandAllModelAction(UITexts.ActionContributor_ExpandAll, configuration);
		expandAllAction.setImageDescriptor(UIIcons.EXPAND_ALL);
		appendToGroup(ISynchronizePageConfiguration.P_TOOLBAR_MENU, ISynchronizePageConfiguration.NAVIGATE_GROUP, expandAllAction);
	}
	
}
