/*******************************************************************************
* Copyright (c) 2007-2011 Guillermo Gonzalez
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.ui.team;

import java.util.HashSet;
import java.util.Set;

import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.IExecutionListener;
import org.eclipse.core.commands.NotHandledException;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.commands.ICommandService;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.listeners.BzrChangeStateEvent;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * A IExecutionListener implementation that hooks into RefreshCommands calls.
 *
 * @author Guillermo Gonzaelz <guillo.gonzo@gmail.com>
 */
public final class RefreshExecutionListener implements IExecutionListener {
	private static final String REFRESH_ID = "org.eclipse.ui.file.refresh";

	public void addTo(ICommandService cmdService) {
		cmdService.getCommand(REFRESH_ID).addExecutionListener(this);
	}

	public void removeFrom(ICommandService cmdService) {
		if(cmdService != null) {
            cmdService.getCommand(REFRESH_ID).removeExecutionListener(this);
        }
	}

	public void notHandled(String commandId, NotHandledException exception) {}

	public void postExecuteFailure(String commandId, ExecutionException exception) {}

	public void postExecuteSuccess(String commandId, Object returnValue) {}

	public void preExecute(String commandId, ExecutionEvent event) {
		IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
		if (window != null && window.getSelectionService().getSelection() instanceof IStructuredSelection) {
			final Set<IResource> resources = new HashSet<IResource>();
			IStructuredSelection structuredSelection = (IStructuredSelection) window.getSelectionService().getSelection();
			for (Object selection : structuredSelection.toList()) {
				if (selection instanceof IAdaptable) {
					IAdaptable adaptable = (IAdaptable) selection;
					final IResource res = (IResource) adaptable.getAdapter(IResource.class);
					if (res != null) {
						final IProject proj = res.getProject();
						BazaarTeamProvider provider = BzrWorkspaceRoot.getProviderFor(proj);
						if (provider != null) {
							resources.add(res);
						}
					}
				}
			}
			if (!resources.isEmpty()) {
				try {
					EclipseBazaarCore.getDefault().getStatusCacheManager().scheduleRefresh(resources, new NullProgressMonitor(), BzrChangeStateEvent.BRANCH_STATE_MODIFY);
				} catch (BazaarException e) {
					EclipseBazaarCore.log(e.getStatus().getMessage(), e.getStatus().getSeverity());
				}
			}
		}
	}
}
