/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.views;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.IJobChangeEvent;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.core.runtime.jobs.JobChangeAdapter;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IMenuListener;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.jface.layout.TableColumnLayout;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.jface.viewers.ArrayContentProvider;
import org.eclipse.jface.viewers.ColumnWeightData;
import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableColumn;
import org.eclipse.ui.IActionBars;
import org.eclipse.ui.IWorkbenchActionConstants;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.actions.BaseSelectionListenerAction;
import org.eclipse.ui.progress.IProgressService;
import org.eclipse.ui.progress.UIJob;
import org.vcs.bazaar.client.BazaarConflictType;
import org.vcs.bazaar.client.IBazaarConflict;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.commandline.syntax.IResolveOptions;
import org.vcs.bazaar.eclipse.core.commands.ConflictsCommand;
import org.vcs.bazaar.eclipse.core.listeners.BzrChangeStateEvent;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.utils.ResourceUtil;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.UIIcons;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.UIUtils;
import org.vcs.bazaar.eclipse.ui.actions.EditConflictsAction;
import org.vcs.bazaar.eclipse.ui.actions.ResolveAction;
import org.vcs.bazaar.eclipse.ui.views.ConflictsViewComparator.Order;

/**
 * @author Piotr Piastucki
 */
public class ConflictsView extends BazaarView {

	public static final String VIEW_ID = "org.vcs.bazaar.eclipse.ui.views.ConflictsView"; //$NON-NLS-1$

	private TableViewer viewer;

	private IBzrBranch branch;
	
	public void resourceStateChanged(BzrChangeStateEvent event) {
		// TODO Auto-generated method stub
	}

	@Override
	public void setFocus() {
		// TODO Auto-generated method stub
	}

	@Override
	public void setInput(Object object) {
		if (object instanceof IBzrBranch) {
			refresh((IBzrBranch) object);
		}
	}

	@Override
	public void createPartControl(Composite parent) {
		Composite container = new Composite(parent, SWT.NONE);
		TableColumnLayout layout = new TableColumnLayout();
		container.setLayout(layout);

		final Table table = new Table(container, SWT.H_SCROLL | SWT.V_SCROLL | SWT.FULL_SELECTION);
		table.setLayout(new GridLayout());
		table.setHeaderVisible(true);
		table.setLinesVisible(true);

		viewer = new TableViewer(table);
		viewer.setContentProvider(new ArrayContentProvider());
		viewer.setLabelProvider(new ConflictListLabelProvider());
		viewer.setComparator(new ConflictsViewComparator(Order.ByType.ascending()));
		// Type
		final TableColumn type = new TableColumn(viewer.getTable(), SWT.LEFT);
		type.setText(UITexts.ConflictsView_typeHeader);
		type.setResizable(true);
		UIUtils.addSizeLimiter(type);
		layout.setColumnData(type, new ColumnWeightData(1));
		// Path
		final TableColumn path = new TableColumn(viewer.getTable(), SWT.LEFT);
		path.setText(UITexts.ConflictsView_pathHeader);
		path.setResizable(true);
		UIUtils.addSizeLimiter(path);
		layout.setColumnData(path, new ColumnWeightData(2));
		// Message
		final TableColumn message = new TableColumn(viewer.getTable(), SWT.LEFT);
		message.setText(UITexts.ConflictsView_messageHeader);
		message.setResizable(false);
		UIUtils.addSizeLimiter(message);
		layout.setColumnData(message, new ColumnWeightData(2));

		table.setSortDirection(SWT.UP);
		table.setSortColumn(type);
		
		addDoubleClickListener();
		contributeToContextMenu();
		contributeToActionBars();
	}

	private void addDoubleClickListener() {
		viewer.addDoubleClickListener(new IDoubleClickListener() {
			public void doubleClick(DoubleClickEvent event) {
				IStructuredSelection selection = (IStructuredSelection) viewer.getSelection();
				if (!selection.isEmpty()) {
					IBazaarConflict conflict = (IBazaarConflict) selection.getFirstElement();
					if (conflict.getType() == BazaarConflictType.TEXT_CONFLICT) {
						editConflict(conflict);
					}
				}
			}
		});
	}

	private void editConflict(IBazaarConflict conflict) {
		final IResource resource = ResourceUtil.getIFileForLocation(branch.getPath().append(conflict.getPath()).toOSString());
		if (resource != null && resource instanceof IFile) {
			IRunnableWithProgress runnable = new IRunnableWithProgress() {
				public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
					EditConflictsAction.runEditConflicts((IFile) resource);
				}
			};
			IProgressService progressService = PlatformUI.getWorkbench().getProgressService();
			try {
				progressService.run(false, false, runnable);
			} catch (InvocationTargetException e) {
			} catch (InterruptedException e) {
			}
		};
	}
	
	private class ConflictViewResolveAction extends BaseSelectionListenerAction {

		private final Option[] options;
		
		protected ConflictViewResolveAction(String text, Option...options) {
			super(text);
			this.options = options;
		}

		@Override
	    public void run() {
			IStructuredSelection sel = getStructuredSelection();
			IBazaarConflict conflict = (IBazaarConflict) sel.getFirstElement();
			final IResource resource = ResourceUtil.getIFileForLocation(branch.getPath().append(conflict.getPath()).toOSString());
			if (resource != null) {
				IRunnableWithProgress runnable = new IRunnableWithProgress() {
					public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
						try {
							ResolveAction.runResolve(monitor, new IResource[]{resource}, options);
						} catch (InvocationTargetException e) {
							throw e;
						} finally {
							refresh(branch);
						}
					}
				};
				IProgressService progressService = PlatformUI.getWorkbench().getProgressService();
				try {
					progressService.run(false, false, runnable);
				} catch (InvocationTargetException e) {
				} catch (InterruptedException e) {
				}
			};
		}
	}
	
	private class ConflictViewEditConflictsAction extends BaseSelectionListenerAction {

		protected ConflictViewEditConflictsAction(String text) {
			super(text);
		}

		@Override
	    public void run() {
			editConflict((IBazaarConflict) getStructuredSelection().getFirstElement());
		}

		@Override
		protected boolean updateSelection(IStructuredSelection selection) {
			if (!selection.isEmpty()) {
				IBazaarConflict conflict = (IBazaarConflict) selection.getFirstElement();
				return conflict.getType() == BazaarConflictType.TEXT_CONFLICT;
			}
			return false;
		}
	}

	private void contributeToContextMenu() {
		final ConflictViewResolveAction markResolvedAction = new ConflictViewResolveAction(UITexts.ActionResolve_label);
		final ConflictViewResolveAction resolveTakeThis = new ConflictViewResolveAction(UITexts.ActionResolveTakeThis_label, IResolveOptions.TAKE_THIS);
		final ConflictViewResolveAction resolveTakeOther = new ConflictViewResolveAction(UITexts.ActionResolveTakeOther_label, IResolveOptions.TAKE_OTHER);
		final ConflictViewEditConflictsAction editConflicts = new ConflictViewEditConflictsAction(UITexts.ActionEditConflicts_label);
		viewer.getTable().addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				IStructuredSelection selection = (IStructuredSelection) viewer.getSelection();
				markResolvedAction.selectionChanged(selection);
				resolveTakeOther.selectionChanged(selection);
				resolveTakeThis.selectionChanged(selection);
				editConflicts.selectionChanged(selection);
			}
		});
		MenuManager menuMgr = new MenuManager();
		Menu menu = menuMgr.createContextMenu(viewer.getTable());
		menuMgr.addMenuListener(new IMenuListener() {
			public void menuAboutToShow(IMenuManager menuMgr) {
				menuMgr.add(new Separator(IWorkbenchActionConstants.GROUP_FILE));
				menuMgr.add(editConflicts);
				menuMgr.add(resolveTakeThis);
				menuMgr.add(resolveTakeOther);
				menuMgr.add(markResolvedAction);
			}
		});
		menuMgr.setRemoveAllWhenShown(true);
		viewer.getTable().setMenu(menu);
	}

	private void contributeToActionBars() {
		IActionBars actionBars = getViewSite().getActionBars();
		Action toggleShowAffectedPathsAction = new Action(UITexts.View_Refresh, UIIcons.REFRESH) {
			@Override
			public void run() {
				refresh(branch);
			}
		};
		IToolBarManager tbm = actionBars.getToolBarManager();
		tbm.add(toggleShowAffectedPathsAction);
		tbm.update(false);
		actionBars.updateActionBars();
	}
	
	private static class ConflictListLabelProvider extends LabelProvider implements ITableLabelProvider {
		public Image getColumnImage(Object element, int columnIndex) {
			return null;
		}
		public String getColumnText(Object element, int columnIndex) {
			if (element instanceof IBazaarConflict) {
		        switch (columnIndex) {
		        case 0:
		            return ((IBazaarConflict)element).getType().toString();
		        case 1:
		            return ((IBazaarConflict)element).getPath();
		        case 2:
		            return ((IBazaarConflict)element).getMessage();
		        }
			}
            return "N/A";
		}
	}
	
	public void refresh(final IBzrBranch branch) {
		this.branch = branch;
		if (branch == null) {
			viewer.setInput(null);
			viewer.refresh();
		} else {
			final List<IBazaarConflict> input = new ArrayList<IBazaarConflict>();
			Job job = new Job(UITexts.ConflictsView_refreshTaskName) {
				@Override
				protected IStatus run(IProgressMonitor monitor) {
					ConflictsCommand cmd = new ConflictsCommand(branch);
					try {
						cmd.run(monitor);
						List<IBazaarConflict> conflicts = cmd.getConflicts();
						if (conflicts != null) {
							input.addAll(conflicts);
						}
					} catch (BazaarException e) {
					}
					return Status.OK_STATUS;
				}
			};
			job.addJobChangeListener(new JobChangeAdapter() {
				@Override
                public void done(IJobChangeEvent event) {
					if(event.getResult().isOK()) {
                        getSite().getShell().getDisplay().asyncExec(new Runnable() {
							public void run() {
								viewer.setInput(input.toArray());
								viewer.refresh();
							}
						});
                    }
				}
			});
			job.setUser(true);
			job.setPriority(UIJob.LONG);
			job.schedule();
		}
	}
	
}
