/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.views;

import java.util.Collections;
import java.util.Comparator;

import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerComparator;
import org.vcs.bazaar.client.BazaarConflictType;
import org.vcs.bazaar.client.IBazaarConflict;

/**
 * @author Piotr Piastucki
 */
public class ConflictsViewComparator extends ViewerComparator {

	public static final BazaarConflictType[] TYPE_ORDER = {
		BazaarConflictType.TEXT_CONFLICT, 
		BazaarConflictType.CONTENTS_CONFLICT,
		BazaarConflictType.PATH_CONFLICT,
		BazaarConflictType.DUPLICATE_ENTRY,
		BazaarConflictType.DUPLICATE_ID,
		BazaarConflictType.PARENT_LOOP,
		BazaarConflictType.MISSING_PARENT,
		BazaarConflictType.DELETING_PARENT,
		BazaarConflictType.UNVERSIONED_PARENT,
		BazaarConflictType.NON_DIRECTORY_PARENT,
		BazaarConflictType.UNKNOWN};

	public static Integer getWeight(BazaarConflictType type) {
		for (int i = 0; i < TYPE_ORDER.length; i ++) {
			if (type == TYPE_ORDER[i]) {
				return i;
			}
		}
		return -1;
	}
	
	public static enum Order implements Comparator<IBazaarConflict> {

		ByType() {
			public int compare(IBazaarConflict o1, IBazaarConflict o2) {
				return getWeight(o1.getType()).compareTo(getWeight(o2.getType()));
			}

		},
		ByPath() {
			public int compare(IBazaarConflict o1, IBazaarConflict o2) {
				return o1.getPath().compareTo(o2.getPath());
			}
		};

		public Comparator<IBazaarConflict> ascending() {
			return this;
		}

		public Comparator<IBazaarConflict> descending() {
			return Collections.reverseOrder(this);
		}
	}
	
	
	public ConflictsViewComparator(Comparator comparator) {
		super(comparator);
	}

	@Override
	public int compare(Viewer viewer, Object e1, Object e2) {
		return getComparator().compare(e1, e2);
	}
}
