/*******************************************************************************
* Copyright (c) 2013 Piotr Piastucki
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
*******************************************************************************/
package org.vcs.bazaar.eclipse.ui.widgets;

import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableColumn;
import org.vcs.bazaar.eclipse.ui.widgets.BzrResourceSelectionComparator.Order;

public class BzrResourceHeaderSelectionListener extends SelectionAdapter {

	private final Order order;
	private final TableViewer viewer;
	
	public BzrResourceHeaderSelectionListener (TableViewer viewer, Order order) {
		this.viewer = viewer;
		this.order = order;
	}
	
	@Override
	public void widgetSelected(SelectionEvent e) {
		TableColumn column = (TableColumn) e.widget;
		Table table = column.getParent();
		int direction = SWT.UP;
		if (column == table.getSortColumn()) {
			direction = table.getSortDirection();
			switch (direction) {
			case SWT.NONE:
				direction = SWT.UP;
				break;
			case SWT.UP:
				direction = SWT.DOWN;
				break;
			case SWT.DOWN:
				// fall through
			default:
				direction = SWT.UP;
				break;
			}
		}
		table.setSortColumn(column);
		table.setSortDirection(direction);
		viewer.setComparator(new BzrResourceSelectionComparator(direction == SWT.DOWN ? order.descending() : order.ascending()));
	}

}
