/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.widgets;

import java.util.Collections;
import java.util.Comparator;

import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerComparator;
import org.vcs.bazaar.client.BazaarStatusKind;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;

/**
 * @author Piotr Piastucki
 */
public class BzrResourceSelectionComparator extends ViewerComparator {

	public static final BazaarStatusKind[] STATUS_ORDER = {
		BazaarStatusKind.HAS_CONFLICTS,
		BazaarStatusKind.CREATED, 
		BazaarStatusKind.MODIFIED,
		BazaarStatusKind.DELETED,
		BazaarStatusKind.RENAMED,
		BazaarStatusKind.KIND_CHANGED,
		BazaarStatusKind.UNKNOWN};

	public static Integer getStatusWeight(IBzrResourceStatus status) {
		for (int i = 0; i < STATUS_ORDER.length; i ++) {
			if (status.contains(STATUS_ORDER[i])) {
				return i;
			}
		}
		return -1;
	}
	
	public static enum Order implements Comparator<IBzrResourceStatus> {

		ByStatus() {
			public int compare(IBzrResourceStatus o1, IBzrResourceStatus o2) {
				int result = getStatusWeight(o1).compareTo(getStatusWeight(o2));
				if (result == 0) {
					result = o1.getStatus().getPath().compareTo(o2.getStatus().getPath()); 
				}
				return result;
			}

		},
		ByFile() {
			public int compare(IBzrResourceStatus o1, IBzrResourceStatus o2) {
				return o1.getStatus().getPath().compareTo(o2.getStatus().getPath());
			}
		};

		public Comparator<IBzrResourceStatus> ascending() {
			return this;
		}

		public Comparator<IBzrResourceStatus> descending() {
			return Collections.reverseOrder(this);
		}
	}
	
	
	public BzrResourceSelectionComparator(Comparator comparator) {
		super(comparator);
	}

	@Override
	public int compare(Viewer viewer, Object e1, Object e2) {
		return getComparator().compare(e1, e2);
	}

}
