/*******************************************************************************
 * Copyright (c) 2013 Piotr Piastucki
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.widgets;

import org.eclipse.compare.CompareUI;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.resource.JFaceResources;
import org.eclipse.jface.resource.LocalResourceManager;
import org.eclipse.jface.resource.ResourceManager;
import org.eclipse.jface.viewers.DecorationOverlayIcon;
import org.eclipse.jface.viewers.IDecoration;
import org.eclipse.swt.graphics.Image;
import org.vcs.bazaar.client.BazaarStatusKind;
import org.vcs.bazaar.eclipse.core.model.BzrStatus;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.ui.decorator.DecoratorImages;

/**
 * @author Piotr Piastucki
 */
public class BzrResourceSelectionStatusLabelProvider extends BzrResourceSelectionPathLabelProvider {

	private ResourceManager resourceManager = new LocalResourceManager(JFaceResources.getResources());

	@Override
	public Image getImage(Object obj) {
		IBzrResourceStatus status = (IBzrResourceStatus) obj;
		Image base = CompareUI.getImage(status.getStatus().getPath());
		if (status.isRenamed()) {
			ImageDescriptor im =  new DecorationOverlayIcon(base, DecoratorImages.getImageDescriptor(new BzrStatus(BazaarStatusKind.RENAMED)), IDecoration.BOTTOM_RIGHT);
			base = (Image) resourceManager.get(im);
		} else if (status.isAdded() 
			|| status.isDeleted() 
			|| status.isUnknown()
			|| status.isHasConflicts()) {
			ImageDescriptor im =  new DecorationOverlayIcon(base, DecoratorImages.getImageDescriptor(status.getStatus()), IDecoration.BOTTOM_RIGHT);
			base = (Image) resourceManager.get(im);
		}
		return base;
	}
	
	@Override
	public String getText(Object obj) {
		return "";
	}

	@Override
	public void dispose() {
		resourceManager.dispose();
		super.dispose();
	}
	
}
