/*******************************************************************************
 * Copyright (c) 2012 Idereal Limited
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Alexander Taler
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.wizards.createproject;

import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Scrollable;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.operations.CheckoutBazaarProjectOperation;
import org.vcs.bazaar.eclipse.ui.preferences.BazaarPreferenceConstants;

/**
 * A specialization of CreateProjectEntry.
 * 
 * Provides a multi selection box to choose the branch type, Branch, Checkout or
 * Lightweight Checkout.
 * 
 * @author Alexander Taler
 */
public class CreateProjectBranchType extends CreateProjectEntry {

    protected Button coButton;
    protected Button brButton;

    public CreateProjectBranchType(Composite parent,
                                   WizardPage page,
                                   CreateProjectWizard wiz,
                                   int width) {
        super(parent, page, wiz, "", width, "");
    }

    @Override
    protected Scrollable createWidget(Composite parent) {

        Group compo = new Group(parent, SWT.NONE);
        compo.setText(UITexts.CreateProjectBranchType_label);
        compo.setLayout(new GridLayout(1, false));

        int type = EclipseBazaarUI.getDefault().getPreferenceStore().getInt(BazaarPreferenceConstants.DEFAULT_BRANCH_TYPE);

        brButton = new Button(compo, SWT.RADIO);
        brButton.setText(UITexts.CreateProjectBranchType_branch);
        brButton.setSelection(type != CheckoutBazaarProjectOperation.TYPE_CHECKOUT);

        coButton = new Button(compo, SWT.RADIO);
        coButton.setText(UITexts.CreateProjectBranchType_checkout);
        coButton.setSelection(type == CheckoutBazaarProjectOperation.TYPE_CHECKOUT);

        return compo;
    }

    @Override
    public void isValid() throws BazaarException {
        return;
    }

    @Override
    public String getValue() {
        return "";
    }

    public int getBranchType() {
    	int type = CheckoutBazaarProjectOperation.TYPE_BRANCH;
        if (coButton.getSelection()) {
            type = CheckoutBazaarProjectOperation.TYPE_CHECKOUT;
        }
        EclipseBazaarUI.getDefault().getPreferenceStore().setValue(BazaarPreferenceConstants.DEFAULT_BRANCH_TYPE, type);
        return type;
    }

    @Override
    public void setValue(String newValue) {
        throw new RuntimeException("setValue not supported");
    }
}
