/*******************************************************************************
 * Copyright (c) 2012 Idereal Limited
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Alexander Taler
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.wizards.createproject;

import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.Path;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.widgets.Composite;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * A widget for entering a project location.
 * 
 * This means checking the validity.
 * 
 * @author Alexander Taler
 */
public class CreateProjectLocation extends CreateProjectEntry {
    public CreateProjectLocation(Composite parent,
        WizardPage page,
        CreateProjectWizard wiz,
        String labelText,
        int width,
        String baseValue)
    {
        super(parent, page, wiz, labelText, width, baseValue);
    }

    @Override
    public void isValid() throws BazaarException {
        // Ensure that it's modified.
        super.isValid();
        IPath loc = new Path(getValue());
        IPath locParent = loc.removeLastSegments(1);
        IPath workBase = new Path(baseValue);
        IPath locDefault = new Path(baseValue + wiz.getProjectName());
        if (loc.equals(workBase)) {
            throw new BazaarException("Project Location cannot be directly in the workspace root");
        }
        if (locParent.equals(workBase) && !loc.equals(locDefault)) {
            throw new BazaarException(
                "Project Location cannot be a folder in the workspace root with a different name from the project.");
        }
        if (loc.toFile().exists()) {
            throw new BazaarException(
                "Project Location not available, file or folder already exists.");
        }
    }
}
