/*******************************************************************************
 * Copyright (c) 2012 Idereal Limited
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Alexander Taler
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.wizards.createproject;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.widgets.Composite;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * A specialization of CreateProjectEntry.
 * 
 * This boils down to one line of code: checking validity of project name. A
 * whole class for that one line seems a bit excessive.
 * 
 * @author Alexander Taler
 */
public class CreateProjectName extends CreateProjectEntry {
    public CreateProjectName(Composite parent,
                                     WizardPage page,
                                     CreateProjectWizard wiz,
                                     String labelText,
                                     int width,
                                     String baseValue) {
        super(parent, page, wiz, labelText, width, baseValue);
    }

    @Override
    public void isValid() throws BazaarException {
        // Ensure that it's modified.
        super.isValid();
        try {
            IProject project = ResourcesPlugin.getWorkspace().getRoot().getProject(getValue());
            if (project.exists()) {
                throw new BazaarException("Project name already taken");
            }
        } catch (IllegalArgumentException iae) {
            throw new BazaarException("Illegal project name");
        }
    }

}
