/*******************************************************************************
 * Copyright (c) 2012 Idereal Limited
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Alexander Taler
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.wizards.createproject;

import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.Scrollable;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.branch.BranchLocationManager;

/**
 * A specialization of CreateProjectEntry.
 * 
 * It uses a Combo widget instead of a Text widget, validates that input is
 * correctly formatted and adds a button to browse the file system for branches.
 * 
 * @author Alexander Taler
 */
public class CreateProjectRemoteBranch extends CreateProjectEntry {

    protected Combo combo;

    private static String labelText =
        "Repository Location\nProvide a URL to a remote repository and branch, or browse for a branch on the local machine";

    public CreateProjectRemoteBranch(Composite parent,
                                     WizardPage page,
                                     CreateProjectWizard wiz,
                                     int width,
                                     String baseValue) {
        super(parent, page, wiz, labelText, width, baseValue);
    }

    @Override
    protected Scrollable createWidget(Composite parent) {
        Composite compo = new Composite(parent, SWT.NONE);
        compo.setLayout(new GridLayout(2, false));

        combo = new Combo(compo, SWT.SINGLE | SWT.BORDER);

        for (IBzrBranch br : BranchLocationManager.getAllBranches()) {
            combo.add(br.getBranchLocation().toString());
        }

        final Button browse = new Button(compo, SWT.PUSH);
        browse.setText("Browse for folder");
        browse.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                final DirectoryDialog dialog = new DirectoryDialog(page.getShell());
                dialog.setMessage("Select folder");
                final String seldir = dialog.open();
                if (seldir != null) {
                    combo.setText(seldir);
                }
            }
        });

        return combo;
    }

    @Override
    public void isValid() throws BazaarException {
        // Ensure that it's modified.
        super.isValid();
    	try {
			new BranchLocation(getValue());
		} catch (BazaarClientException e) {
			throw new BazaarException(e.getMessage());
		}
    }

    @Override
    public String getValue() {
        return combo.getText();
    }

    @Override
    public void setValue(String newValue) {
        combo.setText(newValue);
    }
}
