/*******************************************************************************
 * Copyright (c) 2012 Idereal Limited
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Alexander Taler
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.wizards.createproject;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IMessageProvider;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Scrollable;
import org.eclipse.swt.widgets.Text;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.dialogs.ShowLogDialog;

/**
 * Allow selection of older revisions
 * 
 * Provides an entry box to provide an older revision number.
 * 
 * TODO: Add support for symbolic tags.
 * TODO: Replace with org.vcs.bazaar.eclipse.ui.widgets.RevisionNumber 
 * 
 * @author Alexander Taler
 */
public class CreateProjectRevision extends CreateProjectEntry {

    private static String labelText = "Fetch a specific revision";

    private Button checkBox;
    private Button showLog;

    public CreateProjectRevision(Composite parent,
                                 WizardPage page,
                                 CreateProjectWizard wiz,
                                 int width) {
        super(parent, page, wiz, labelText, width, "");
    }

    @Override
    protected Scrollable createWidget(Composite parent) {
        Composite compo = new Composite(parent, SWT.NONE);
        compo.setLayout(new GridLayout(3, false));

        checkBox = new Button(compo, SWT.CHECK);
        checkBox.setText("Use older revision");
        checkBox.setSelection(false);

        text = new Text(compo, SWT.BORDER);
        GridData gridData = new GridData(SWT.VERTICAL);
        gridData.widthHint = 50;
        text.setLayoutData(gridData);
        text.setEnabled(false);

        // Enable revision text box iff it's enabled.
        checkBox.addListener(SWT.Selection, new Listener() {
            public void handleEvent(Event event) {
                text.setEnabled(checkBox.getSelection());
            }
        });

        // Add the showlog button
        showLog = new Button(compo, SWT.PUSH);
        showLog.setText("View Revision Log");
        showLog.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                try {
                    checkBox.setSelection(true);
                    final ShowLogDialog dialog =
                        new ShowLogDialog(page.getShell(), wiz.getRemoteBranch());
                    if (dialog.open() == Dialog.OK && dialog.getSelectedRevision() != null) {
                        text.setText(dialog.getSelectedRevision().getValue());
                    }
                } catch (BazaarException be) {
                    // SetErrorMessage is not displaying. I have not investigated.
                    String message = be.getStatus().getMessage();
                    if ((message != null) && (message.length() > 0)) {
                        page.setMessage(message, IMessageProvider.WARNING);
                    }
                }
            }
        });

        return compo;
    }

    @Override
    public void isValid() throws BazaarException {
        return;
    }
}
